@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2020 Kai Pastor
+ *    Copyright 2012-2020, 2024, 2025 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -792,42 +792,35 @@ void LineSymbol::processContinuousLine(
         MapCoordVectorF& processed_coords,
         ObjectRenderables& output ) const
 {
-	auto mid_symbol_distance_f = length_type(0.001) * mid_symbol_distance;
-	auto mid_symbols_length   = (qMax(1, mid_symbols_per_spot) - 1) * mid_symbol_distance_f;
-	auto effective_end_length = end.clen;
-	
-	auto split = start;
-	
-	set_mid_symbols = set_mid_symbols && mid_symbol && !mid_symbol->isEmpty() && mid_symbols_per_spot;
-	if (set_mid_symbols && mid_symbols_length <= effective_end_length - split.clen)
-	{
-		auto mid_position = (split.clen + effective_end_length - mid_symbols_length) / 2;
-		auto next_split = SplitPathCoord::at(mid_position, split);
-		path.copy(split, next_split, processed_flags, processed_coords);
-		split = next_split;
-		
-		auto orientation = qreal(0);
-		bool mid_symbol_rotatable = bool(mid_symbol) && mid_symbol->isRotatable();
-		for (auto i = mid_symbols_per_spot; i > 0; --i)
-		{
-			if (mid_symbol_rotatable)
-				orientation = split.tangentVector().angle();
-			mid_symbol->createRenderablesScaled(split.pos, orientation, output);
-			
-			if (i > 1)
-			{
-				mid_position += mid_symbol_distance_f;
-				next_split = SplitPathCoord::at(mid_position, split);
-				path.copy(split, next_split, processed_flags, processed_coords);
-				split = next_split;
-			}
-		}
-	}
-	
-	path.copy(split, end, processed_flags, processed_coords);
-	
+	path.copy(start, end, processed_flags, processed_coords);
 	processed_flags.back().setGapPoint(true);
 	Q_ASSERT(!processed_flags[processed_flags.size()-2].isCurveStart());
+	
+	set_mid_symbols = set_mid_symbols && mid_symbol && !mid_symbol->isEmpty() && mid_symbols_per_spot;
+	if (!set_mid_symbols)
+		return;
+	
+	const auto mid_symbol_distance_f = length_type(0.001) * mid_symbol_distance;
+	const auto mid_symbols_length = (qMax(1, mid_symbols_per_spot) - 1) * mid_symbol_distance_f;
+	if (mid_symbols_length <= end.clen - start.clen)
+	{
+		const auto mid_symbol_rotatable = mid_symbol->isRotatable();
+		
+		auto mid_position = (start.clen + end.clen - mid_symbols_length) / 2;
+		auto next_split = SplitPathCoord::at(mid_position, start);
+		auto orientation = qreal(0);
+		if (mid_symbol_rotatable)
+			orientation = next_split.tangentVector().angle();
+		mid_symbol->createRenderablesScaled(next_split.pos, orientation, output);
+		for (auto i = 2; i <= mid_symbols_per_spot; ++i)
+		{
+			mid_position += mid_symbol_distance_f;
+			next_split = SplitPathCoord::at(mid_position, next_split);
+			if (mid_symbol_rotatable)
+				orientation = next_split.tangentVector().angle();
+			mid_symbol->createRenderablesScaled(next_split.pos, orientation, output);
+		}
+	}
 }
 
 void LineSymbol::createPointedLineCap(
@@ -1201,7 +1194,7 @@ SplitPathCoord LineSymbol::createDashGroups(
 				bool is_first_dash = is_first_dashgroup && dash == 1;
 				bool is_last_dash  = is_last_dashgroup  && dash == dashes_in_group;
 				
-				// The dash has an start if it is not the first dash in a half first group.
+				// The dash has a start if it is not the first dash in a half first group.
 				bool has_start = !(is_first_dash && half_first_group);
 				// The dash has an end if it is not the last dash in a half last group.
 				bool has_end   = !(is_last_dash && half_last_group);
@@ -1238,15 +1231,25 @@ SplitPathCoord LineSymbol::createDashGroups(
 			
 			if (dashgroup < num_dashgroups)
 			{
-				if (Q_UNLIKELY(mid_symbols == CenterOfGap))
+				if (mid_symbols == CenterOfGap)
 				{
 					auto position = cur_length
 					                + (break_length_f
 					                   - mid_symbol_distance_f * (mid_symbols_per_spot - 1)) / 2;
-					auto split = dash_start;
+					// 'dash_start' is now the begin of the gap.
+					// 'CenterOfGap' is meant for symbols placed in the gap only.
+					// But actual required length can be longer. Output symbols
+					// from 'start' to 'end' and omit everything outside this range.
+					auto split = (position >= dash_start.clen) ? dash_start : start;
 					for (int i = 0; i < mid_symbols_per_spot; ++i, position += mid_symbol_distance_f)
 					{
+						if (position < start.clen)
+							continue;
+						
 						split = SplitPathCoord::at(position, split);
+						if (position > end.clen)
+							break;
+						
 						if (mid_symbol_rotatable)
 							orientation = split.tangentVector().angle();
 						mid_symbol->createRenderablesScaled(split.pos, orientation, output);
@@ -1768,6 +1771,12 @@ const Symbol::BorderHints* LineSymbol::borderHints() const
 }
 
 
+// virtual
+bool LineSymbol::containsDashSymbol() const {
+	return dash_symbol != nullptr;
+}
+
+
 
 void LineSymbol::setStartSymbol(PointSymbol* symbol)
 {
