@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2017 Kai Pastor
+ *    Copyright 2012-2020, 2025 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -21,8 +21,6 @@
 
 #include "area_symbol_settings.h"
 
-#include <memory>
-
 #include <Qt>
 #include <QtGlobal>
 #include <QtMath>
@@ -80,10 +78,14 @@ AreaSymbolSettings::AreaSymbolSettings(AreaSymbol* symbol, SymbolSettingDialog*
 	
 	auto general_layout = new QFormLayout();
 	
+	// TODO: Revise label
+	oriented_to_north = new QCheckBox(QCoreApplication::translate("OpenOrienteering::PointSymbolEditorWidget", "Always oriented to north (not rotatable)"));
+	general_layout->addRow(oriented_to_north);
+	
 	color_edit = new ColorDropDown(map);
 	general_layout->addRow(tr("Area color:"), color_edit);
 	
-	minimum_size_edit = Util::SpinBox::create(1, 0.0, 999999.9, trUtf8("mm²"));
+	minimum_size_edit = Util::SpinBox::create(1, 0.0, 999999.9, tr("mm²"));
 	general_layout->addRow(tr("Minimum size:"), minimum_size_edit);
 	
 	general_layout->addItem(Util::SpacerItem::create(this));
@@ -248,6 +250,7 @@ AreaSymbolSettings::AreaSymbolSettings(AreaSymbol* symbol, SymbolSettingDialog*
 	area_tab->setLayout(layout);
 	addPropertiesGroup(tr("Area settings"), area_tab);
 	
+	connect(oriented_to_north, &QCheckBox::clicked, this, &AreaSymbolSettings::orientedToNorthClicked);
 	connect(color_edit, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &AreaSymbolSettings::colorChanged);
 	connect(minimum_size_edit, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &AreaSymbolSettings::minimumSizeChanged);
 	connect(del_pattern_button, &QAbstractButton::clicked, this, &AreaSymbolSettings::deleteActivePattern);
@@ -295,7 +298,9 @@ void AreaSymbolSettings::reset(Symbol* symbol)
 
 void AreaSymbolSettings::updateAreaGeneral()
 {
-	ScopedMultiSignalsBlocker block(color_edit, minimum_size_edit);
+	ScopedMultiSignalsBlocker block(oriented_to_north, color_edit, minimum_size_edit);
+	oriented_to_north->setEnabled(symbol->getNumFillPatterns() != 0);
+	oriented_to_north->setChecked(!symbol->isRotatable());
 	color_edit->setColor(symbol->getColor());
 	minimum_size_edit->setValue(0.001 * symbol->minimum_area);
 }
@@ -321,7 +326,7 @@ void AreaSymbolSettings::loadPatterns()
 		pattern_list->addItem(pattern.name);
 		if (pattern.type == AreaSymbol::FillPattern::PointPattern)
 		{
-			auto editor = new PointSymbolEditorWidget(controller, pattern.point, 16);
+			auto editor = new PointSymbolEditorWidget(controller, pattern.point, PointSymbolEditorWidget::AreaSymbolElement, 16);
 			connect(editor, &PointSymbolEditorWidget::symbolEdited, this, &SymbolPropertiesWidget::propertiesModified );
 			addPropertiesGroup(pattern.name, editor);
 		}
@@ -447,11 +452,12 @@ void AreaSymbolSettings::addPattern(AreaSymbol::FillPattern::Type type)
 	Q_ASSERT(int(symbol->patterns.size()) == pattern_list->count());
 	
 	active_pattern->type = type;
+	active_pattern->setRotatable(!oriented_to_north->isChecked());
 	if (type == AreaSymbol::FillPattern::PointPattern)
 	{
 		active_pattern->point = new PointSymbol();
 		active_pattern->point->setRotatable(true);
-		auto editor = new PointSymbolEditorWidget(controller, active_pattern->point, 16);
+		auto editor = new PointSymbolEditorWidget(controller, active_pattern->point, PointSymbolEditorWidget::AreaSymbolElement, 16);
 		connect(editor, &PointSymbolEditorWidget::symbolEdited, this, &SymbolPropertiesWidget::propertiesModified );
 		if (pattern_list->currentRow() == int(symbol->patterns.size()) - 1)
 		{
@@ -507,10 +513,17 @@ void AreaSymbolSettings::selectPattern(int index)
 {
 	active_pattern = symbol->patterns.begin() + index;
 	updatePatternWidgets();
+	updateAreaGeneral();
 }
 
 
 
+void AreaSymbolSettings::orientedToNorthClicked(bool checked)
+{
+	symbol->setRotatable(!checked);
+	emit propertiesModified();
+}
+
 void AreaSymbolSettings::colorChanged()
 {
 	symbol->color = color_edit->color();
