@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2019 Kai Pastor
+ *    Copyright 2012-2019, 2024, 2025 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -23,12 +23,11 @@
 
 #include <algorithm>
 #include <limits>
-#include <memory>
-// IWYU pragma: no_include <ext/alloc_traits.h>
+// IWYU pragma: no_include <memory>
+// IWYU pragma: no_include <vector>
 
 #include <Qt>
 #include <QAbstractItemView>
-#include <QBoxLayout>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QCursor>
@@ -52,6 +51,7 @@
 #include <QPointF>
 #include <QPushButton>
 #include <QRectF>
+#include <QSignalBlocker>
 #include <QSizePolicy>
 #include <QStackedWidget>
 #include <QStringList>
@@ -73,28 +73,20 @@
 #include "gui/util_gui.h"
 #include "gui/widgets/color_dropdown.h"
 #include "util/backports.h"  // IWYU pragma: keep
-
-// IWYU pragma: no_forward_declare QBoxLayout
-// IWYU pragma: no_forward_declare QGridLayout
-// IWYU pragma: no_forward_declare QHBoxLayout
-// IWYU pragma: no_forward_declare QMenu
-// IWYU pragma: no_forward_declare QTableWidgetItem
-// IWYU pragma: no_forward_declare QVBoxLayout
+#include "util/scoped_signals_blocker.h"
 
 
 namespace OpenOrienteering {
 
-PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller, PointSymbol* symbol, qreal offset_y, bool permanent_preview, QWidget* parent)
+PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller, PointSymbol* symbol, SymbolRole role, qreal offset_y, QWidget* parent)
 : QWidget(parent)
 , symbol(symbol)
 , object_origin_coord(0, offset_y)
 , offset_y(offset_y)
+, map(controller->getMap())
 , controller(controller)
-, permanent_preview(permanent_preview)
+, permanent_preview(role == PrimarySymbol)
 {
-	map = controller->getMap();
-	
-	midpoint_object = nullptr;
 	if (permanent_preview)
 	{
 		midpoint_object = new PointObject(symbol);
@@ -104,19 +96,20 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	
 	oriented_to_north = new QCheckBox(tr("Always oriented to north (not rotatable)"));
 	oriented_to_north->setChecked(!symbol->isRotatable());
+	oriented_to_north->setVisible(role != AreaSymbolElement);
 	
-	QLabel* elements_label = Util::Headline::create(tr("Elements"));
+	auto* elements_label = Util::Headline::create(tr("Elements"));
 	element_list = new QListWidget();
 	initElementList();
 	
 	delete_element_button = new QPushButton(QIcon(QString::fromLatin1(":/images/minus.png")), QString{});
-	QToolButton* add_element_button = new QToolButton();
+	auto* add_element_button = new QToolButton();
 	add_element_button->setIcon(QIcon(QString::fromLatin1(":/images/plus.png")));
 	add_element_button->setToolButtonStyle(Qt::ToolButtonIconOnly);
 	add_element_button->setPopupMode(QToolButton::InstantPopup);
 	add_element_button->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
 	add_element_button->setMinimumSize(delete_element_button->sizeHint());
-	QMenu* add_element_button_menu = new QMenu(add_element_button);
+	auto* add_element_button_menu = new QMenu(add_element_button);
 	add_element_button_menu->addAction(tr("Point"), this, SLOT(addPointClicked()));
 	add_element_button_menu->addAction(tr("Line"), this, SLOT(addLineClicked()));
 	add_element_button_menu->addAction(tr("Area"), this, SLOT(addAreaClicked()));
@@ -124,28 +117,28 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	
 	center_all_elements_button = new QPushButton(tr("Center all elements"));
 	
-	QLabel* current_element_label = Util::Headline::create(tr("Current element"));
+	auto* current_element_label = Util::Headline::create(tr("Current element"));
 	
 	element_properties_widget = new QStackedWidget();
 	
 	// Point (circle)
 	point_properties = new QWidget();
-	QLabel* point_inner_radius_label = new QLabel(tr("Diameter <b>a</b>:"));
+	auto* point_inner_radius_label = new QLabel(tr("Diameter <b>a</b>:"));
 	point_inner_radius_edit = Util::SpinBox::create(2, 0.0, 99999.9, tr("mm"));
 	
-	QLabel* point_inner_color_label = new QLabel(tr("Inner color:"));
+	auto* point_inner_color_label = new QLabel(tr("Inner color:"));
 	point_inner_color_edit = new ColorDropDown(map);
 	
-	QLabel* point_outer_width_label = new QLabel(tr("Outer width <b>b</b>:"));
+	auto* point_outer_width_label = new QLabel(tr("Outer width <b>b</b>:"));
 	point_outer_width_edit = Util::SpinBox::create(2, 0.0, 99999.9, tr("mm"));
 	
-	QLabel* point_outer_color_label = new QLabel(tr("Outer color:"));
+	auto* point_outer_color_label = new QLabel(tr("Outer color:"));
 	point_outer_color_edit = new ColorDropDown(map);
 	
-	QLabel* explanation_label = new QLabel();
+	auto* explanation_label = new QLabel();
 	explanation_label->setPixmap(QPixmap(QString::fromLatin1(":/images/symbol_point_explanation.png")));
 	
-	QGridLayout* point_layout = new QGridLayout();
+	auto* point_layout = new QGridLayout();
 	point_layout->setContentsMargins(0, 0, 0, 0);
 	point_layout->addWidget(point_inner_radius_label, 0, 0);
 	point_layout->addWidget(point_inner_radius_edit, 0, 1);
@@ -164,20 +157,20 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	
 	// Line
 	line_properties = new QWidget();
-	QLabel* line_width_label = new QLabel(tr("Line width:"));
+	auto* line_width_label = new QLabel(tr("Line width:"));
 	line_width_edit = Util::SpinBox::create(3, 0.0, 99999.9, tr("mm"));
 	
-	QLabel* line_color_label = new QLabel(tr("Line color:"));
+	auto* line_color_label = new QLabel(tr("Line color:"));
 	line_color_edit = new ColorDropDown(map);
 	
-	QLabel* line_cap_label = new QLabel(tr("Line cap:"));
+	auto* line_cap_label = new QLabel(tr("Line cap:"));
 	line_cap_edit = new QComboBox();
 	line_cap_edit->addItem(tr("flat"), QVariant(LineSymbol::FlatCap));
 	line_cap_edit->addItem(tr("round"), QVariant(LineSymbol::RoundCap));
 	line_cap_edit->addItem(tr("square"), QVariant(LineSymbol::SquareCap));
 	//line_cap_edit->addItem(tr("pointed"), QVariant(LineSymbol::PointedCap));	// this would require another input field for the cap length
 	
-	QLabel* line_join_label = new QLabel(tr("Line join:"));
+	auto* line_join_label = new QLabel(tr("Line join:"));
 	line_join_edit = new QComboBox();
 	line_join_edit->addItem(tr("miter"), QVariant(LineSymbol::MiterJoin));
 	line_join_edit->addItem(tr("round"), QVariant(LineSymbol::RoundJoin));
@@ -185,7 +178,7 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	
 	line_closed_check = new QCheckBox(tr("Line closed"));
 	
-	QGridLayout* line_layout = new QGridLayout();
+	auto* line_layout = new QGridLayout();
 	line_layout->setContentsMargins(0, 0, 0, 0);
 	line_layout->addWidget(line_width_label, 0, 0);
 	line_layout->addWidget(line_width_edit, 0, 1);
@@ -203,10 +196,10 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	
 	// Area
 	area_properties = new QWidget();
-	QLabel* area_color_label = new QLabel(tr("Area color:"));
+	auto* area_color_label = new QLabel(tr("Area color:"));
 	area_color_edit = new ColorDropDown(map);
 	
-	QGridLayout* area_layout = new QGridLayout();
+	auto* area_layout = new QGridLayout();
 	area_layout->setContentsMargins(0, 0, 0, 0);
 	area_layout->addWidget(area_color_label, 0, 0);
 	area_layout->addWidget(area_color_edit, 0, 1);
@@ -224,7 +217,7 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	coords_table->setHorizontalHeaderLabels(QStringList() << tr("X") << tr("Y") << tr("Curve start"));
 	coords_table->verticalHeader()->setVisible(false);
 	
-	QHeaderView* header_view = coords_table->horizontalHeader();
+	auto* header_view = coords_table->horizontalHeader();
 	header_view->setSectionResizeMode(0, QHeaderView::Interactive);
 	header_view->setSectionResizeMode(1, QHeaderView::Interactive);
 	header_view->setSectionResizeMode(2, QHeaderView::ResizeToContents);
@@ -235,11 +228,11 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	center_coords_button = new QPushButton(tr("Center by coordinate average"));
 	
 	// Layout
-	QBoxLayout* left_layout = new QVBoxLayout();
+	auto* left_layout = new QVBoxLayout();
 	
 	left_layout->addWidget(elements_label);
 	left_layout->addWidget(element_list, 1);
-	QGridLayout* element_buttons_layout = new QGridLayout();
+	auto* element_buttons_layout = new QGridLayout();
 	element_buttons_layout->setColumnStretch(0, 1);
 	element_buttons_layout->addWidget(add_element_button, 1, 2);
 	element_buttons_layout->addWidget(delete_element_button, 1, 3);
@@ -247,7 +240,7 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	element_buttons_layout->setColumnStretch(5, 1);
 	left_layout->addLayout(element_buttons_layout);
 	
-	QBoxLayout* right_layout = new QVBoxLayout();
+	auto* right_layout = new QVBoxLayout();
 	right_layout->setMargin(0);
 	
 	right_layout->addWidget(current_element_label);
@@ -256,19 +249,19 @@ PointSymbolEditorWidget::PointSymbolEditorWidget(MapEditorController* controller
 	
 	right_layout->addWidget(coords_label);
 	right_layout->addWidget(coords_table);
-	QHBoxLayout* coords_buttons_layout = new QHBoxLayout();
+	auto* coords_buttons_layout = new QHBoxLayout();
 	coords_buttons_layout->addWidget(add_coord_button);
 	coords_buttons_layout->addWidget(delete_coord_button);
 	coords_buttons_layout->addStretch(1);
 	coords_buttons_layout->addWidget(center_coords_button);
 	right_layout->addLayout(coords_buttons_layout);
 	
-	QBoxLayout* columns_layout = new QHBoxLayout;
+	auto* columns_layout = new QHBoxLayout;
 	columns_layout->addLayout(left_layout);
 	columns_layout->addSpacing(16);
 	columns_layout->addLayout(right_layout);
 	
-	QVBoxLayout* layout = new QVBoxLayout();
+	auto* layout = new QVBoxLayout();
 	layout->addWidget(oriented_to_north);
 	layout->addSpacerItem(Util::SpacerItem::create(this));
 	layout->addLayout(columns_layout);
@@ -345,14 +338,14 @@ void PointSymbolEditorWidget::setVisible(bool visible)
 
 bool PointSymbolEditorWidget::changeCurrentCoordinate(const MapCoordF& new_coord)
 {
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	if (object == midpoint_object)
 		return false;
 	
 	if (object->getType() == Object::Point)
 	{
-		auto point = static_cast<PointObject*>(object);
-		MapCoordF coord = point->getCoordF();
+		auto* point = static_cast<PointObject*>(object);
+		auto coord = point->getCoordF();
 		coord.setX(new_coord.x());
 		coord.setY(new_coord.y() - offset_y);
 		point->setPosition(coord);
@@ -363,7 +356,7 @@ bool PointSymbolEditorWidget::changeCurrentCoordinate(const MapCoordF& new_coord
 		if (table_row < 0)
 			return false;
 		
-		PathObject* path = object->asPath();
+		auto* path = object->asPath();
 		
 		auto coord_index = MapCoordVector::size_type(table_row);
 		Q_ASSERT(coord_index < path->getCoordinateCount());
@@ -382,14 +375,14 @@ bool PointSymbolEditorWidget::changeCurrentCoordinate(const MapCoordF& new_coord
 
 bool PointSymbolEditorWidget::addCoordinate(const MapCoordF& new_coord)
 {
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	if (object == midpoint_object)
 		return false;
 	
 	if (object->getType() == Object::Point)
 		return changeCurrentCoordinate(new_coord);
 	Q_ASSERT(object->getType() == Object::Path);
-	auto path = static_cast<PathObject*>(object);
+	auto* path = static_cast<PathObject*>(object);
 	
 	auto table_row = coords_table->currentRow();
 	if (table_row < 0)
@@ -419,7 +412,7 @@ void PointSymbolEditorWidget::initElementList()
 	element_list->addItem(tr("[Midpoint]"));	// NOTE: Is that item needed?
 	for (int i = 0; i < symbol->getNumElements(); ++i)
 	{
-		Symbol* element_symbol = symbol->getElementSymbol(i);
+		auto* element_symbol = symbol->getElementSymbol(i);
 		element_list->addItem(getLabelForSymbol(element_symbol));
 	}
 	element_list->setCurrentRow(0);
@@ -438,46 +431,44 @@ void PointSymbolEditorWidget::changeElement(int row)
 	
 	if (row >= 0)
 	{
-		Symbol* element_symbol = getCurrentElementSymbol();
-		Object* object = getCurrentElementObject();
+		auto* element_symbol = getCurrentElementSymbol();
+		auto* object = getCurrentElementObject();
 		
 		if (object->getType() == Object::Path)
 		{
-			auto path = static_cast<PathObject*>(object);
+			auto* path = static_cast<PathObject*>(object);
 			if (element_symbol->getType() == Symbol::Line)
 			{
-				line_width_edit->blockSignals(true);
-				line_color_edit->blockSignals(true);
-				line_cap_edit->blockSignals(true);
-				line_join_edit->blockSignals(true);
-				line_closed_check->blockSignals(true);
-				
-				auto line = static_cast<LineSymbol*>(element_symbol);
-				line_width_edit->setValue(0.001 * line->getLineWidth());
-				line_color_edit->setColor(line->getColor());
-				line_cap_edit->setCurrentIndex(line_cap_edit->findData(QVariant(line->getCapStyle())));
-				line_join_edit->setCurrentIndex(line_join_edit->findData(QVariant(line->getJoinStyle())));
-				
-				const auto& parts = path->parts();
-				line_closed_check->setChecked(!parts.empty() && parts.front().isClosed());
-				line_closed_check->setEnabled(!parts.empty());
-				
-				line_width_edit->blockSignals(false);
-				line_color_edit->blockSignals(false);
-				line_cap_edit->blockSignals(false);
-				line_join_edit->blockSignals(false);
-				line_closed_check->blockSignals(false);
+				{
+					const ScopedMultiSignalsBlocker block(
+					  line_width_edit,
+					  line_color_edit,
+					  line_cap_edit,
+					  line_join_edit,
+					  line_closed_check
+					);
+					
+					auto* line = static_cast<LineSymbol*>(element_symbol);
+					line_width_edit->setValue(0.001 * line->getLineWidth());
+					line_color_edit->setColor(line->getColor());
+					line_cap_edit->setCurrentIndex(line_cap_edit->findData(QVariant(line->getCapStyle())));
+					line_join_edit->setCurrentIndex(line_join_edit->findData(QVariant(line->getJoinStyle())));
+					
+					const auto& parts = path->parts();
+					line_closed_check->setChecked(!parts.empty() && parts.front().isClosed());
+					line_closed_check->setEnabled(!parts.empty());
+				}
 				
 				element_properties_widget->setCurrentWidget(line_properties);
 			}
 			else if (element_symbol->getType() == Symbol::Area)
 			{
-				area_color_edit->blockSignals(true);
-				
-				auto area = static_cast<AreaSymbol*>(element_symbol);
-				area_color_edit->setColor(area->getColor());
-				
-				area_color_edit->blockSignals(false);
+				{
+					const QSignalBlocker blocker(area_color_edit);
+					
+					auto* area = static_cast<AreaSymbol*>(element_symbol);
+					area_color_edit->setColor(area->getColor());
+				}
 				
 				element_properties_widget->setCurrentWidget(area_properties);
 			}
@@ -490,21 +481,20 @@ void PointSymbolEditorWidget::changeElement(int row)
 		}
 		else
 		{
-			point_inner_radius_edit->blockSignals(true);
-			point_inner_color_edit->blockSignals(true);
-			point_outer_width_edit->blockSignals(true);
-			point_outer_width_edit->blockSignals(true);
-			
-			auto point = static_cast<PointSymbol*>(element_symbol);
-			point_inner_radius_edit->setValue(2 * 0.001 * point->getInnerRadius());
-			point_inner_color_edit->setColor(point->getInnerColor());
-			point_outer_width_edit->setValue(0.001 * point->getOuterWidth());
-			point_outer_color_edit->setColor(point->getOuterColor());
-			
-			point_inner_radius_edit->blockSignals(false);
-			point_inner_color_edit->blockSignals(false);
-			point_outer_width_edit->blockSignals(false);
-			point_outer_width_edit->blockSignals(false);
+			{
+				const ScopedMultiSignalsBlocker block(
+				  point_inner_radius_edit,
+				  point_inner_color_edit,
+				  point_outer_width_edit,
+				  point_outer_color_edit
+				);
+				
+				auto* point = static_cast<PointSymbol*>(element_symbol);
+				point_inner_radius_edit->setValue(2 * 0.001 * point->getInnerRadius());
+				point_inner_color_edit->setColor(point->getInnerColor());
+				point_outer_width_edit->setValue(0.001 * point->getOuterWidth());
+				point_outer_color_edit->setColor(point->getOuterColor());
+			}
 			
 			element_properties_widget->setCurrentWidget(point_properties);
 			
@@ -528,24 +518,24 @@ void PointSymbolEditorWidget::changeElement(int row)
 
 void PointSymbolEditorWidget::addPointClicked()
 {
-	PointSymbol* new_point = new PointSymbol();
-	PointObject* new_object = new PointObject(new_point);
+	auto* new_point = new PointSymbol();
+	auto* new_object = new PointObject(new_point);
 	
 	insertElement(new_object, new_point);
 }
 
 void PointSymbolEditorWidget::addLineClicked()
 {
-	LineSymbol* new_line = new LineSymbol();
-	PathObject* new_object = new PathObject(new_line);
+	auto* new_line = new LineSymbol();
+	auto* new_object = new PathObject(new_line);
 	
 	insertElement(new_object, new_line);
 }
 
 void PointSymbolEditorWidget::addAreaClicked()
 {
-	AreaSymbol* new_area = new AreaSymbol();
-	PathObject* new_object = new PathObject(new_area);
+	auto* new_area = new AreaSymbol();
+	auto* new_object = new PathObject(new_area);
 	
 	insertElement(new_object, new_area);
 }
@@ -556,6 +546,7 @@ void PointSymbolEditorWidget::deleteCurrentElement()
 	Q_ASSERT(row > 0);
 	delete element_list->item(row);
 	symbol->deleteElement(row - 1);
+	center_all_elements_button->setEnabled(symbol->getNumElements() > 0);
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
 }
@@ -570,7 +561,7 @@ void PointSymbolEditorWidget::centerAllElements()
 	
 	for (int i = 0; i < symbol->getNumElements(); ++i)
 	{
-		Object* object = symbol->getElementObject(i);
+		auto* object = symbol->getElementObject(i);
 		for (const auto& coord : object->getRawCoordinateVector())
 		{
 			min_x = std::min(min_x, coord.nativeX());
@@ -588,7 +579,7 @@ void PointSymbolEditorWidget::centerAllElements()
 		
 		for (int i = 0; i < symbol->getNumElements(); ++i)
 		{
-			auto object = symbol->getElementObject(i);
+			auto* object = symbol->getElementObject(i);
 			object->move(-center_x, -center_y);
 			object->update();
 		}
@@ -601,7 +592,7 @@ void PointSymbolEditorWidget::centerAllElements()
 
 void PointSymbolEditorWidget::pointInnerRadiusChanged(double value)
 {
-	auto symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
 	symbol->inner_radius = qRound(1000 * 0.5 * value);
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -609,7 +600,7 @@ void PointSymbolEditorWidget::pointInnerRadiusChanged(double value)
 
 void PointSymbolEditorWidget::pointInnerColorChanged()
 {
-	auto symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
 	symbol->inner_color = point_inner_color_edit->color();
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -617,7 +608,7 @@ void PointSymbolEditorWidget::pointInnerColorChanged()
 
 void PointSymbolEditorWidget::pointOuterWidthChanged(double value)
 {
-	auto symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
 	symbol->outer_width = qRound(1000 * value);
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -625,7 +616,7 @@ void PointSymbolEditorWidget::pointOuterWidthChanged(double value)
 
 void PointSymbolEditorWidget::pointOuterColorChanged()
 {
-	auto symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<PointSymbol*>(getCurrentElementSymbol());
 	symbol->outer_color = point_outer_color_edit->color();
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -633,7 +624,7 @@ void PointSymbolEditorWidget::pointOuterColorChanged()
 
 void PointSymbolEditorWidget::lineWidthChanged(double value)
 {
-	auto symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
 	symbol->line_width = qRound(1000 * value);
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -641,7 +632,7 @@ void PointSymbolEditorWidget::lineWidthChanged(double value)
 
 void PointSymbolEditorWidget::lineColorChanged()
 {
-	auto symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
 	symbol->color = line_color_edit->color();
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -649,7 +640,7 @@ void PointSymbolEditorWidget::lineColorChanged()
 
 void PointSymbolEditorWidget::lineCapChanged(int index)
 {
-	auto symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
 	symbol->cap_style = static_cast<LineSymbol::CapStyle>(line_cap_edit->itemData(index).toInt());
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -657,7 +648,7 @@ void PointSymbolEditorWidget::lineCapChanged(int index)
 
 void PointSymbolEditorWidget::lineJoinChanged(int index)
 {
-	auto symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<LineSymbol*>(getCurrentElementSymbol());
 	symbol->join_style = static_cast<LineSymbol::JoinStyle>(line_join_edit->itemData(index).toInt());
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -665,26 +656,27 @@ void PointSymbolEditorWidget::lineJoinChanged(int index)
 
 void PointSymbolEditorWidget::lineClosedClicked(bool checked)
 {
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	Q_ASSERT(object->getType() == Object::Path);
-	auto path = static_cast<PathObject*>(object);
+	auto* path = static_cast<PathObject*>(object);
 	
 	if (!checked && path->getCoordinateCount() >= 4 && path->getCoordinate(path->getCoordinateCount() - 4).isCurveStart())
 		path->getCoordinateRef(path->getCoordinateCount() - 4).setCurveStart(false);
 	
 	Q_ASSERT(!path->parts().empty());
-	path->parts().front().setClosed(checked, true);
+	path->parts().front().setClosed(checked, path->getCoordinateCount() > 2);
 	if (!checked)
 		path->deleteCoordinate(path->getCoordinateCount() - 1, false);
 	
 	updateCoordsTable();
+	updateDeleteCoordButton();
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
 }
 
 void PointSymbolEditorWidget::areaColorChanged()
 {
-	auto symbol = static_cast<AreaSymbol*>(getCurrentElementSymbol());
+	auto* symbol = static_cast<AreaSymbol*>(getCurrentElementSymbol());
 	symbol->color = area_color_edit->color();
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -692,7 +684,7 @@ void PointSymbolEditorWidget::areaColorChanged()
 
 void PointSymbolEditorWidget::coordinateChanged(int row, int column)
 {
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	if (!object || !midpoint_object)
 		return;
 	
@@ -703,12 +695,12 @@ void PointSymbolEditorWidget::coordinateChanged(int row, int column)
 		auto coord = MapCoord{};
 		if (object->getType() == Object::Point)
 		{
-			auto point = static_cast<PointObject*>(object);
+			auto* point = static_cast<PointObject*>(object);
 			coord = point->getCoord();
 		}
 		else if (object->getType() == Object::Path)
 		{
-			auto path = static_cast<const PathObject*>(object);
+			auto* path = static_cast<const PathObject*>(object);
 			Q_ASSERT(coord_index < path->getCoordinateCount());
 			coord = path->getCoordinate(coord_index);
 		}
@@ -726,12 +718,12 @@ void PointSymbolEditorWidget::coordinateChanged(int row, int column)
 			
 			if (object->getType() == Object::Point)
 			{
-				auto point = static_cast<PointObject*>(object);
+				auto* point = static_cast<PointObject*>(object);
 				point->setPosition(coord);
 			}
 			else if (object->getType() == Object::Path)
 			{
-				auto path = static_cast<PathObject*>(object);
+				auto* path = static_cast<PathObject*>(object);
 				path->setCoordinate(coord_index, coord);
 			}
 			
@@ -740,18 +732,18 @@ void PointSymbolEditorWidget::coordinateChanged(int row, int column)
 		}
 		
 		// Update, needed in cases of rounding and error
-		coords_table->blockSignals(true);
+		const QSignalBlocker blocker(coords_table);
 		coords_table->item(row, column)->setText(locale.toString((column == 0) ? coord.x() : -coord.y(), 'f', 3));
-		coords_table->blockSignals(false);
 	}
 	else
 	{
 		Q_ASSERT(object->getType() == Object::Path);
-		auto path = static_cast<PathObject*>(object);
+		auto* path = static_cast<PathObject*>(object);
 		Q_ASSERT(coord_index < path->getCoordinateCount());
 		auto coord = path->getCoordinate(coord_index);
 		coord.setCurveStart(coords_table->item(row, column)->checkState() == Qt::Checked);
 		path->setCoordinate(coord_index, coord);
+		updateDeleteCoordButton();
 		
 		updateCoordsTable();
 		map->updateAllObjectsWithSymbol(symbol);
@@ -761,34 +753,68 @@ void PointSymbolEditorWidget::coordinateChanged(int row, int column)
 
 void PointSymbolEditorWidget::addCoordClicked()
 {
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	Q_ASSERT(object->getType() == Object::Path);
-	auto path = static_cast<PathObject*>(object);
-	
-	if (coords_table->currentRow() < 0)
-		path->addCoordinate(MapCoordVector::size_type(coords_table->rowCount()), MapCoord(0, 0));
-	else
-		path->addCoordinate(MapCoordVector::size_type(coords_table->currentRow()) + 1, path->getCoordinate(MapCoordVector::size_type(coords_table->currentRow())));
+	auto* path = static_cast<PathObject*>(object);
 	
 	int row = (coords_table->currentRow() < 0) ? coords_table->rowCount() : (coords_table->currentRow() + 1);
+	int col = qMax(0, coords_table->currentColumn());
+	do
+	{
+		if (coords_table->currentRow() < 0)
+		{
+			path->addCoordinate(MapCoordVector::size_type(coords_table->rowCount()), MapCoord(0, 0));
+		}
+		else
+		{
+			auto coord_index = MapCoordVector::size_type(coords_table->currentRow());
+			auto current_coord = path->getCoordinate(coord_index);
+			current_coord.setCurveStart(false);
+			current_coord.setHolePoint(false);
+			path->addCoordinate(coord_index, current_coord);
+		}
+	}
+	while (path->getCoordinateCount() < (path->getSymbol()->getType() == Symbol::Area ? 3 : 2));
+	
 	updateCoordsTable();	// NOTE: incremental updates (to the curve start boxes) would be possible but mean some implementation effort
-	coords_table->setCurrentItem(coords_table->item(row, coords_table->currentColumn()));
+	coords_table->setCurrentItem(coords_table->item(row, col));
+	map->updateAllObjectsWithSymbol(symbol);
+	emit symbolEdited();
 }
 
 void PointSymbolEditorWidget::deleteCoordClicked()
 {
-	Object* object = getCurrentElementObject();
-	Q_ASSERT(object->getType() == Object::Path);
-	auto path = static_cast<PathObject*>(object);
-	
 	int row = coords_table->currentRow();
 	if (row < 0)
 		return;
 	
-	path->deleteCoordinate(MapCoordVector::size_type(row), false);
+	auto* object = getCurrentElementObject();
+	Q_ASSERT(object->getType() == Object::Path);
+	auto* path = static_cast<PathObject*>(object);
+	
+	// To maintain a table-like UX, avoid high-level behavior of deleteCoordinate().
+	// (1) Deleting inside a curve: Turn off curve start to retain table UX.
+	auto look_back_distance = path->parts().front().isClosed() ? 2 : 3;
+	for (int i = qMax(int(path->parts().front().first_index), row - look_back_distance); i <= row; ++i)
+	{
+		path->getCoordinateRef(MapCoordVector::size_type(i)).setCurveStart(false);
+	}
+	// (2) Deleting first row: Avoid removal of curve start at second row.
+	if (row == 0)
+	{
+		// Avoid special behavior of deleteCoordinate()
+		auto is_curve_start = path->getCoordinate(1).isCurveStart();
+		path->getCoordinateRef(1).setCurveStart(false);
+		path->deleteCoordinate(0, false);
+		path->getCoordinateRef(0).setCurveStart(is_curve_start);
+	}
+	else
+	{
+		path->deleteCoordinate(MapCoordVector::size_type(row), false);
+	}
 	
 	updateCoordsTable();	// NOTE: incremental updates (to the curve start boxes) would be possible but mean some implementation effort
-	center_coords_button->setEnabled(path->getCoordinateCount() > 0);
+	coords_table->selectRow(qMax(0, row - 1));
 	updateDeleteCoordButton();
 	map->updateAllObjectsWithSymbol(symbol);
 	emit symbolEdited();
@@ -796,19 +822,19 @@ void PointSymbolEditorWidget::deleteCoordClicked()
 
 void PointSymbolEditorWidget::centerCoordsClicked()
 {
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	
 	if (object->getType() == Object::Point)
 	{
-		auto point = static_cast<PointObject*>(object);
+		auto* point = static_cast<PointObject*>(object);
 		point->setPosition(0, 0);
 	}
 	else
 	{
 		Q_ASSERT(object->getType() == Object::Path);
-		auto path = static_cast<PathObject*>(object);
+		auto* path = static_cast<PathObject*>(object);
 		
-		MapCoordF center = MapCoordF(0, 0);
+		auto center = MapCoordF(0, 0);
 		auto size = path->getCoordinateCount();
 		auto change_size = (!path->parts().empty() && path->parts().front().isClosed()) ? (size - 1) : size;
 		
@@ -828,18 +854,20 @@ void PointSymbolEditorWidget::centerCoordsClicked()
 
 void PointSymbolEditorWidget::updateCoordsTable()
 {
-	Object* object = getCurrentElementObject();
-	int num_rows;
-	if (object->getType() == Object::Point)
-		num_rows = 1;
-	else
+	auto* object = getCurrentElementObject();
+	int num_rows = 1;
+	if (object->getType() == Object::Path)
 	{
-		auto path = static_cast<PathObject*>(object);
+		auto* path = static_cast<const PathObject*>(object);
 		num_rows = int(path->getCoordinateCount());
 		if (num_rows > 0 && path->parts().front().isClosed())
 			--num_rows;
 		if (path->getSymbol()->getType() == Symbol::Line)
-			line_closed_check->setEnabled(num_rows > 0);
+		{
+			const QSignalBlocker blocker(line_closed_check);
+			line_closed_check->setChecked(num_rows > 0 && path->parts().front().isClosed());
+			line_closed_check->setEnabled(num_rows > 2 || line_closed_check->isChecked());
+		}
 	}
 	
 	coords_table->setRowCount(num_rows);
@@ -847,36 +875,40 @@ void PointSymbolEditorWidget::updateCoordsTable()
 		addCoordsRow(i);
 	
 	center_coords_button->setEnabled(num_rows > 0);
+	updateDeleteCoordButton();
 }
 
 void PointSymbolEditorWidget::addCoordsRow(int row)
 {
 	coords_table->setRowHeight(row, coords_table->fontMetrics().height() + 2);
 	
-	coords_table->blockSignals(true);
+	const QSignalBlocker blocker(coords_table);
 	
 	for (int c = 0; c < 3; ++c)
 	{
 		if (!coords_table->item(row, c))
 		{
-			QTableWidgetItem* item = new QTableWidgetItem();
-			if (c < 2)
+			auto* item = new QTableWidgetItem();
+			switch (c)
 			{
-				item->setFlags(Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable);
+			case 0:
+			case 1:
+				item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsEditable);
 				item->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
+				break;
+			default:
+				item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 			}
 			coords_table->setItem(row, c, item);
 		}
 	}
 	updateCoordsRow(row);
-	
-	coords_table->blockSignals(false);
 }
 
 void PointSymbolEditorWidget::updateCoordsRow(int row)
 {
 	Q_ASSERT(element_list->currentRow() > 0);
-	Object* object = getCurrentElementObject();
+	auto* object = getCurrentElementObject();
 	auto coord_index = MapCoordVector::size_type(row);
 	
 	MapCoordF coordF(0, 0);
@@ -891,42 +923,53 @@ void PointSymbolEditorWidget::updateCoordsRow(int row)
 	
 	if (object->getType() == Object::Path)
 	{
-		auto path = static_cast<const PathObject*>(object);
+		auto* path = static_cast<const PathObject*>(object);
 		bool has_curve_start_box = coord_index+3 < path->getCoordinateCount()
-		                           && (!path->getCoordinate(coord_index+1).isCurveStart() && !path->getCoordinate(coord_index+2).isCurveStart())
-		                           && (row <= 0 || !path->getCoordinate(coord_index-1).isCurveStart())
-		                           && (row <= 1 || !path->getCoordinate(coord_index-2).isCurveStart());
+		                           && (!path->getCoordinate(coord_index+1).isCurveStart() && !path->getCoordinate(coord_index+2).isCurveStart());
+		auto is_curve_part = false;
+		if ( (row > 1 && path->getCoordinate(coord_index-2).isCurveStart())
+		     || (row > 0 && path->getCoordinate(coord_index-1).isCurveStart()) )
+		{
+			has_curve_start_box = false;
+			is_curve_part = true;
+		}
+		auto* item = coords_table->item(row, 2);
 		if (has_curve_start_box)
 		{
-			coords_table->item(row, 2)->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsUserCheckable);
-			coords_table->item(row, 2)->setCheckState(path->getCoordinate(coord_index).isCurveStart() ? Qt::Checked : Qt::Unchecked);
-			return;
+			item->setFlags(item->flags().setFlag(Qt::ItemIsUserCheckable, true));
+			item->setCheckState(path->getCoordinate(coord_index).isCurveStart() ? Qt::Checked : Qt::Unchecked);
+		}
+		else if (is_curve_part)
+		{
+			item->setFlags(item->flags().setFlag(Qt::ItemIsUserCheckable, false));
+			item->setCheckState(Qt::PartiallyChecked);
+		}
+		else
+		{
+			item->setData(Qt::CheckStateRole, {});
 		}
 	}
-
-	if (coords_table->item(row, 2)->flags() & Qt::ItemIsUserCheckable)
-		coords_table->setItem(row, 2, new QTableWidgetItem());	// remove checkbox by replacing the item with a new one - is there a better way?
-	coords_table->item(row, 2)->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 }
 
 void PointSymbolEditorWidget::updateDeleteCoordButton()
 {
-	const bool has_coords = coords_table->rowCount() > 0;
-	const bool is_point = getCurrentElementObject()->getType() == Object::Point;
-	bool part_of_curve = false;
-	
-	if (!is_point)
+	auto enabled = false;
+	switch (getCurrentElementObject()->getSymbol()->getType())
 	{
-		auto path = static_cast<const PathObject*>(getCurrentElementObject());
-		for (int i = 1; i < 4; i++)
+	case Symbol::Line:
+		if (!line_closed_check->isChecked())
 		{
-			int row = coords_table->currentRow() - i;
-			if (row >= 0 && path->getCoordinate(MapCoordVector::size_type(row)).isCurveStart())
-				part_of_curve = true;
+			enabled = coords_table->rowCount() > 2;
+			break;
 		}
+		Q_FALLTHROUGH();
+	case Symbol::Area:
+		enabled = coords_table->rowCount() > 3;
+		break;
+	default:
+		;
 	}
-
-	delete_coord_button->setEnabled(has_coords && !is_point && !part_of_curve);
+	delete_coord_button->setEnabled(enabled);
 }
 
 void PointSymbolEditorWidget::insertElement(Object* object, Symbol* element_symbol)
@@ -1032,15 +1075,15 @@ void PointSymbolEditorActivity::init()
 
 void PointSymbolEditorActivity::update()
 {
-	QRectF rect = QRectF(0.0, symbol_editor->offset_y, 0.0, 0.0);
+	auto rect = QRectF(0.0, symbol_editor->offset_y, 0.0, 0.0);
 	map->setActivityBoundingBox(rect, cross_radius + 1);
 }
 
 void PointSymbolEditorActivity::draw(QPainter* painter, MapWidget* map_widget)
 {
-	QPoint midpoint = map_widget->mapToViewport(symbol_editor->object_origin_coord).toPoint();
+	auto midpoint = map_widget->mapToViewport(symbol_editor->object_origin_coord).toPoint();
 	
-	QPen pen = QPen(Qt::white);
+	auto pen = QPen(Qt::white);
 	pen.setWidth(3);
 	painter->setPen(pen);
 	painter->drawLine(midpoint + QPoint(0, -cross_radius), midpoint + QPoint(0, cross_radius));
