@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2017 Kai Pastor
+ *    Copyright 2012-2018, 2021, 2024 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -41,6 +41,7 @@
 #include <QMessageBox>
 #include <QPalette>
 #include <QShowEvent>
+#include <QString>
 #include <QStringList>
 #include <QStyle>
 #include <QStyleOption>
@@ -52,18 +53,29 @@
 
 #include "core/map.h"
 #include "core/map_color.h"
+#include "core/symbols/symbol.h"
 #include "gui/color_dialog.h"
 #include "gui/main_window.h"
 #include "gui/util_gui.h"
 #include "gui/widgets/segmented_button_layout.h"
 #include "util/item_delegates.h"
-#include "util/util.h"
 
 // IWYU pragma: no_forward_declare QTableWidgetItem
 
 
 namespace OpenOrienteering {
 
+namespace {
+
+/// Local wrapper for Util::ToolButton::create() adding the What's This bit.
+QToolButton* createToolButton(const QIcon& icon, const QString& text)
+{
+	return Util::ToolButton::create(icon, text, "color_dock_widget.html");
+}
+
+}  // anonymous namespace
+
+
 ColorListWidget::ColorListWidget(Map* map, MainWindow* window, QWidget* parent)
 : QWidget(parent)
 , map(map)
@@ -71,8 +83,6 @@ ColorListWidget::ColorListWidget(Map* map, MainWindow* window, QWidget* parent)
 {
 	react_to_changes = true;
 	
-	setWhatsThis(Util::makeWhatThis("color_dock_widget.html"));
-	
 	// Color table
 	color_table = new QTableWidget(map->getNumColors(), 7);
 	color_table->setEditTriggers(QAbstractItemView::SelectedClicked | QAbstractItemView::AnyKeyPressed);
@@ -91,18 +101,18 @@ ColorListWidget::ColorListWidget(Map* map, MainWindow* window, QWidget* parent)
 	duplicate_action->setIcon(QIcon(QString::fromLatin1(":/images/tool-duplicate.png")));
 	
 	// Buttons
-	auto new_button = newToolButton(QIcon(QString::fromLatin1(":/images/plus.png")), tr("New"));
+	auto new_button = createToolButton(QIcon(QString::fromLatin1(":/images/plus.png")), tr("New"));
 	new_button->setPopupMode(QToolButton::DelayedPopup); // or MenuButtonPopup
 	new_button->setMenu(new_button_menu);
-	delete_button = newToolButton(QIcon(QString::fromLatin1(":/images/minus.png")), tr("Delete"));
+	delete_button = createToolButton(QIcon(QString::fromLatin1(":/images/minus.png")), tr("Delete"));
 	
 	auto add_remove_layout = new SegmentedButtonLayout();
 	add_remove_layout->addWidget(new_button);
 	add_remove_layout->addWidget(delete_button);
 	
-	move_up_button = newToolButton(QIcon(QString::fromLatin1(":/images/arrow-up.png")), tr("Move Up"));
+	move_up_button = createToolButton(QIcon(QString::fromLatin1(":/images/arrow-up.png")), tr("Move Up"));
 	move_up_button->setAutoRepeat(true);
-	move_down_button = newToolButton(QIcon(QString::fromLatin1(":/images/arrow-down.png")), tr("Move Down"));
+	move_down_button = createToolButton(QIcon(QString::fromLatin1(":/images/arrow-down.png")), tr("Move Down"));
 	move_down_button->setAutoRepeat(true);
 	
 	auto up_down_layout = new SegmentedButtonLayout();
@@ -110,10 +120,10 @@ ColorListWidget::ColorListWidget(Map* map, MainWindow* window, QWidget* parent)
 	up_down_layout->addWidget(move_down_button);
 	
 	// TODO: In Mapper >= 0.6, switch to ColorWidget (or generic) translation context.
-	edit_button = newToolButton(QIcon(QString::fromLatin1(":/images/settings.png")), QApplication::translate("OpenOrienteering::MapEditorController", "&Edit").remove(QLatin1Char('&')));
+	edit_button = createToolButton(QIcon(QString::fromLatin1(":/images/settings.png")), QApplication::translate("OpenOrienteering::MapEditorController", "&Edit").remove(QLatin1Char('&')));
 	edit_button->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 	
-	auto help_button = newToolButton(QIcon(QString::fromLatin1(":/images/help.png")), tr("Help"));
+	auto help_button = createToolButton(QIcon(QString::fromLatin1(":/images/help.png")), tr("Help"));
 	help_button->setAutoRaise(true);
 	
 	// The buttons row layout
@@ -151,11 +161,16 @@ ColorListWidget::ColorListWidget(Map* map, MainWindow* window, QWidget* parent)
 	header_view->resizeSections(QHeaderView::ResizeToContents);
 	header_view->setSectionResizeMode(0, QHeaderView::Fixed); // Color
 	header_view->resizeSection(0, 32);
-	header_view->setSectionResizeMode(1, QHeaderView::Stretch); // Name
-	header_view->setSectionResizeMode(1, QHeaderView::Interactive); // Spot colors
 	header_view->setSectionResizeMode(5, QHeaderView::Fixed); // Knockout
 	header_view->resizeSection(5, 32);
 	header_view->setSectionsClickable(false);
+	if (map->getNumColors() == 0)
+	{
+		header_view->resizeSection(1, 160); // Name
+		header_view->resizeSection(2, 128); // Spot colors
+		header_view->resizeSection(3, 96);  // CMYK
+		header_view->resizeSection(4, 64);  // RGB
+	}
 	
 	currentCellChange(color_table->currentRow(), 0, 0, 0);	// enable / disable move color buttons
 	
@@ -196,18 +211,6 @@ void ColorListWidget::showEvent(QShowEvent* event)
 }
 
 
-
-QToolButton* ColorListWidget::newToolButton(const QIcon& icon, const QString& text)
-{
-	auto button = new QToolButton();
-	button->setToolButtonStyle(Qt::ToolButtonIconOnly);
-	button->setToolTip(text);
-	button->setIcon(icon);
-	button->setText(text);
-	button->setWhatsThis(whatsThis());
-	return button;
-}
-
 void ColorListWidget::newColor()
 {
 	int row = color_table->currentRow();
@@ -220,6 +223,85 @@ void ColorListWidget::newColor()
 	editCurrentColor();
 }
 
+bool ColorListWidget::confirmColorDeletion(const MapColor* color_to_be_removed) const
+{
+	QString detailed_text;
+	
+	std::vector<const Symbol*> remaining_symbols;
+	remaining_symbols.reserve(std::size_t(map->getNumSymbols()));
+	{
+		// First: direct usage in symbols
+		QString direct_usage;
+		map->applyOnAllSymbols(
+			[&direct_usage, &remaining_symbols, color_to_be_removed](const Symbol* symbol) {
+				if (symbol->getType() == Symbol::NoSymbol)
+					return;
+				if (symbol->containsColor(color_to_be_removed))
+					direct_usage += symbol->getNumberAndPlainTextName() + QChar::LineFeed;
+				else
+					remaining_symbols.push_back(symbol);
+			}
+		);
+		if (!direct_usage.isEmpty())
+		{
+			detailed_text += tr("This color is used by the following symbols:") + QChar::LineFeed
+							 + direct_usage + QChar::LineFeed;
+		}
+	}
+	
+	if (color_to_be_removed->getSpotColorMethod() == MapColor::SpotColor)
+	{
+		// Second: usage as spot color
+		QString spotcolor_usage;
+		std::vector<const MapColor*> affected_colors;
+		affected_colors.reserve(std::size_t(map->getNumColors()));
+		map->applyOnMatchingColors(
+			[&spotcolor_usage, &affected_colors](const auto* color) {
+				spotcolor_usage += color->getName() + QChar::LineFeed;
+				affected_colors.push_back(color);
+			},
+			[&color_to_be_removed](const auto* color) {
+				return color->hasSpotColorComponent(color_to_be_removed);
+			}
+		);
+		if (!affected_colors.empty())
+		{
+			detailed_text += tr("This color is used as a spot color by the following map colors:") + QChar::LineFeed
+							 + spotcolor_usage + QChar::LineFeed;
+			
+			// Third: Additional transitive usage via spot color composition
+			QString transitive_usage;
+			for (const auto* symbol : remaining_symbols)
+			{
+				for (const auto* color : affected_colors)
+				{
+					if (symbol->containsColor(color))
+					{
+						transitive_usage += symbol->getNumberAndPlainTextName() + QChar::LineFeed;
+						break;
+					}
+				}
+			}
+			if (!transitive_usage.isEmpty())
+			{
+				detailed_text += tr("This spot color is used by the following symbols:") + QChar::LineFeed
+								 + transitive_usage;
+			}
+		}
+	}
+		
+	if (detailed_text.isEmpty())
+		return true;
+	
+	QMessageBox msgBox;
+	msgBox.setWindowTitle(tr("Confirmation"));
+	msgBox.setIcon(QMessageBox::Warning);
+	msgBox.setText(tr("Color \"%1\" is used by other elements. Removing the color will change the appearance of these elements. Do you really want to remove it?").arg(color_to_be_removed->getName()));
+	msgBox.setDetailedText(detailed_text);
+	msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+	return msgBox.exec() == QMessageBox::Yes;
+}
+
 void ColorListWidget::deleteColor()
 {
 	int row = color_table->currentRow();
@@ -227,11 +309,8 @@ void ColorListWidget::deleteColor()
 	if (row < 0) return; // In release mode
 	
 	// Show a warning if the color is used
-	if (map->isColorUsedByASymbol(map->getColor(row)))
-	{
-		if (QMessageBox::warning(this, tr("Confirmation"), tr("The map contains symbols with this color. Deleting it will remove the color from these objects! Do you really want to do that?"), QMessageBox::Yes | QMessageBox::No) == QMessageBox::No)
-			return;
-	}
+	if (!confirmColorDeletion(map->getColor(row)))
+		return;
 	
 	map->deleteColor(row);
 	
@@ -410,7 +489,7 @@ void ColorListWidget::addRow(int row)
 		color_table->setItem(row, col, item);
 	}
 	
-#if 0 // Interfers with translation
+#if 0 // Interferes with translation
 	// Name
 	item = color_table->item(row, 1);
 	item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable);
