@@ -1,5 +1,5 @@
 /*
- *    Copyright 2015 Kai Pastor
+ *    Copyright 2015-2019 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -19,6 +19,7 @@
 
 #include "crs_param_widgets.h"
 
+#include <QAbstractButton>
 #include <QCompleter>
 #include <QHBoxLayout>
 #include <QLineEdit>
@@ -39,35 +40,44 @@
 
 namespace OpenOrienteering {
 
+namespace  {
+
+QStringList makeZoneList()
+{
+	QStringList zone_list;
+	zone_list.reserve((60 + 9) * 2);
+	for (int i = 1; i <= 60; ++i)
+	{
+		QString zone = QString::number(i);
+		zone_list << QString::fromLatin1("%1 N").arg(zone) << QString::fromLatin1("%1 S").arg(zone);
+		if (i < 10)
+			zone_list << QString::fromLatin1("0%1 N").arg(zone) << QString::fromLatin1("0%1 S").arg(zone);
+	}
+	return zone_list;
+}
+
+}  // namespace
+
+
+
 UTMZoneEdit::UTMZoneEdit(CRSParameterWidgetObserver& observer, QWidget* parent)
  : QWidget(parent)
  , observer(observer)
 {
-	static const QRegExp zone_regexp(QString::fromLatin1("(?:[0-5]?[1-9]|[1-6]0)(?: [NS])?"));
-	static QStringList zone_list;
-	if (zone_list.isEmpty())
-	{
-		zone_list.reserve((60 + 9) * 2);
-		for (int i = 1; i <= 60; ++i)
-		{
-			QString zone = QString::number(i);
-			zone_list << QString::fromLatin1("%1 N").arg(zone) << QString::fromLatin1("%1 S").arg(zone);
-			if (i < 10)
-				zone_list << QString::fromLatin1("0%1 N").arg(zone) << QString::fromLatin1("0%1 S").arg(zone);
-		}
-	}
+	auto const zone_regexp = QRegExp(QString::fromLatin1("(?:[0-5]?[1-9]|[1-6]0)(?: [NS])?"));
+	auto const zone_list = makeZoneList();
 	
 	line_edit = new QLineEdit();
 	line_edit->setValidator(new QRegExpValidator(zone_regexp, line_edit));
-	QCompleter* completer = new QCompleter(zone_list, line_edit);
+	auto* completer = new QCompleter(zone_list, line_edit);
 	completer->setMaxVisibleItems(4);
 	line_edit->setCompleter(completer);
-	connect(line_edit, &QLineEdit::textChanged, this, &UTMZoneEdit::textEdited);
+	connect(line_edit, &QLineEdit::textChanged, this, &UTMZoneEdit::textChanged);
 	
-	QPushButton* button = new QPushButton(tr("Calculate"));
-	connect(button, &QPushButton::clicked, this, &UTMZoneEdit::calculateValue);
+	auto* button = new QPushButton(tr("Calculate"));
+	connect(button, &QAbstractButton::clicked, this, &UTMZoneEdit::calculateValue);
 	
-	QHBoxLayout* layout = new QHBoxLayout();
+	auto* layout = new QHBoxLayout();
 	layout->setMargin(0);
 	layout->addWidget(line_edit, 1);
 	layout->addWidget(button, 0);
@@ -76,19 +86,18 @@ UTMZoneEdit::UTMZoneEdit(CRSParameterWidgetObserver& observer, QWidget* parent)
 	calculateValue();
 }
 
-UTMZoneEdit::~UTMZoneEdit()
-{
-	// nothing, not inlined
-}
+// This non-inline definition is required to emit a (single) vtable.
+UTMZoneEdit::~UTMZoneEdit() = default;
+
 
 QString UTMZoneEdit::text() const
 {
 	return line_edit->text();
 }
 
-void UTMZoneEdit::setText(const QString& value)
+void UTMZoneEdit::setText(const QString& text)
 {
-	line_edit->setText(value);
+	line_edit->setText(text);
 }
 
 bool UTMZoneEdit::calculateValue()
