@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2020 Kai Pastor
+ *    Copyright 2012-2020, 2025 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -964,8 +964,12 @@ void TemplateListWidget::changeGeorefClicked()
 	auto* templ = currentTemplate();
 	if (templ && templ->canChangeTemplateGeoreferenced())
 	{
-		auto new_value = !templ->isTemplateGeoreferenced();
-		if (new_value)
+		if (!templ->trySetTemplateGeoreferenced(!templ->isTemplateGeoreferenced(), this))
+		{
+			QMessageBox::warning(this, tr("Error"), tr("Cannot change the georeferencing state."));
+		}
+		georef_action->setChecked(templ->isTemplateGeoreferenced());
+		if (templ->isTemplateGeoreferenced())
 		{
 			// Properly tear down positioning activities
 			if (move_by_hand_action->isChecked())
@@ -975,11 +979,6 @@ void TemplateListWidget::changeGeorefClicked()
 			if (position_action->isChecked())
 				position_action->trigger();
 		}
-		if (!templ->trySetTemplateGeoreferenced(new_value, this))
-		{
-			QMessageBox::warning(this, tr("Error"), tr("Cannot change the georeferencing state."));
-			georef_action->setChecked(templ->isTemplateGeoreferenced());
-		}
 	}
 }
 
