@@ -1,5 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
+ *    Copyright 2020 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -23,6 +24,7 @@
 
 #include <memory>
 
+#include <Qt>
 #include <QWidget>
 #include <QObject>
 #include <QString>
@@ -33,86 +35,59 @@ class QAction;
 class QBoxLayout;
 class QCheckBox;
 class QEvent;
-class QIcon;
-class QTableWidget;
+class QModelIndex;
+class QTableView;
 class QToolButton;
+class QVariant;
 
 namespace OpenOrienteering {
 
 class Map;
 class MapEditorController;
 class Template;
+class TemplateTableModel;
 
 
 /**
  * Widget showing the list of templates, including the map layer.
+ * 
  * Allows to load templates, set their view properties and reorder them,
  * and do various other actions like adjusting template positions.
  */
 class TemplateListWidget : public QWidget
 {
-Q_OBJECT
+	Q_OBJECT
+	
 public:
-	TemplateListWidget(Map* map, MapView* main_view, MapEditorController* controller, QWidget* parent = nullptr);
+	static std::unique_ptr<Template> showOpenTemplateDialog(QWidget* dialog_parent, MapEditorController& controller);
+	
 	~TemplateListWidget() override;
 	
-	void addTemplateAt(Template* new_template, int pos);
-	
-	static std::unique_ptr<Template> showOpenTemplateDialog(QWidget* dialog_parent, MapEditorController* controller);
-	
-public slots:
-	/**
-	 * Sets or clears the all-templates-hidden state.
-	 * When all templates are hidden, operations on templates are disabled.
-	 */
-	void setAllTemplatesHidden(bool value);
+	TemplateListWidget(Map& map, MapView& main_view, MapEditorController& controller, QWidget* parent = nullptr);
+	TemplateListWidget(const TemplateListWidget&) = delete;
+	TemplateListWidget(TemplateListWidget&&) = delete;
+	TemplateListWidget& operator=(const TemplateListWidget&) = delete;
+	TemplateListWidget& operator=(TemplateListWidget&&) = delete;
 	
 signals:
+	void currentRowChanged(int row);
+	void currentTemplateChanged(const OpenOrienteering::Template* temp);
+	void closePositionDockWidget();
 	void closeClicked();
 	
 protected:
-	/**
-	 * When key events for Qt::Key_Space are sent to the template_table,
-	 * this will toggle the visibility of the current template.
-	 */
-	bool eventFilter(QObject* watched, QEvent* event) override;
+	TemplateTableModel* model();
+	const TemplateTableModel* model() const { return static_cast<const TemplateTableModel*>(const_cast<TemplateListWidget*>(this)->model()); }
+	QVariant data(int row, int column, int role) const;
+	void setData(int row, int column, QVariant value, int role);
+	Qt::ItemFlags flags(int row, int column) const;
 	
-	/**
-	 * Returns a new QToolButton with a unified appearance.
-	 */
-	QToolButton* newToolButton(const QIcon& icon, const QString& text);
-	
-protected slots:
-	void newTemplate(QAction* action);
-	void openTemplate();
-	void deleteTemplate();
-	void duplicateTemplate();
-	void moveTemplateUp();
-	void moveTemplateDown();
-	void showHelp();
-	
-	void cellChange(int row, int column);
-	void updateButtons();
-	void cellClicked(int row, int column);
-	void cellDoubleClicked(int row, int column);
-	
-	void moveByHandClicked(bool checked);
-	void adjustClicked(bool checked);
-	void adjustWindowClosed();
-	//void groupClicked();
-	void positionClicked(bool checked);
-	void importClicked();
-	void changeGeorefClicked();
-	void moreActionClicked(QAction* action);
-	void vectorizeClicked();
-	
-	void templateAdded(int pos, const OpenOrienteering::Template* temp);
-	void templatePositionDockWidgetClosed(OpenOrienteering::Template* temp);
-	
-	void changeTemplateFile(int pos);
-	
-	void showOpacitySlider(int row);
+	int currentRow() const;
+	int posFromRow(int row) const;
+	int rowFromPos(int pos) const;
+	Template* currentTemplate();
 	
+protected:
 	/**
 	 * Reacts to feature visibility changes.
 	 * 
@@ -120,22 +95,65 @@ protected slots:
 	 */
 	void updateVisibility(OpenOrienteering::MapView::VisibilityFeature feature, bool active, const OpenOrienteering::Template* temp = nullptr);
 	
-private:
-	void updateAll();
-	void addRowItems(int row);
-	void updateRow(int row);
-	int posFromRow(int row);
-	int rowFromPos(int pos);
-	Template* getCurrentTemplate();
+	/**
+	 * Updates widget state depending on general template visibility.
+	 *
+	 * When all templates are hidden, operations on templates are disabled.
+	 */
+	void updateAllTemplatesHidden();
 	
-	Map* map;
-	MapView* main_view;
-	MapEditorController* controller;
+	void setButtonsDirty();
+	void updateButtons();
+	
+	void itemClicked(const QModelIndex& index);
+	void itemDoubleClicked(const QModelIndex& index);
+	
+	/**
+	 * When key events for Qt::Key_Space are sent to the template_table,
+	 * this will toggle the visibility of the current template.
+	 */
+	bool eventFilter(QObject* watched, QEvent* event) override;
+	
+	
+// slots:
+#if 0
+	void newTemplate(QAction* action);
+#endif
+	
+	void openTemplate();
+	void deleteTemplate();
+	void duplicateTemplate();
+	void moveTemplateUp();
+	void moveTemplateDown();
+	void showHelp();
+	
+	void moveByHandClicked(bool checked);
+	void adjustClicked(bool checked);
+	//void groupClicked();
+	void positionClicked(bool checked);
+	void importClicked();
+	void changeGeorefClicked();
+	void moreActionClicked(QAction* action);
+	void vectorizeClicked();
+	
+	void templatePositionDockWidgetClosed(OpenOrienteering::Template* temp);
+	
+	void changeTemplateFile(int pos);
+	
+	void showOpacitySlider(int row);
+	
+private:
+	Map& map;
+	MapView& main_view;
+	MapEditorController& controller;
 	bool mobile_mode;
-	int name_column;
+	bool buttons_dirty = false;
+	
+	Template* last_template = nullptr;
+	int last_row = -1;
 	
 	QCheckBox* all_hidden_check;
-	QTableWidget* template_table;
+	QTableView* template_table;
 	QBoxLayout* all_templates_layout;
 	
 	QAction* duplicate_action;
