@@ -27,8 +27,8 @@
  */
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ****************************************************************************/
 
@@ -67,12 +67,9 @@ QT_BEGIN_NAMESPACE
 inline QPaintEngine::PaintEngineFeatures qt_pdf_decide_features()
 {
     QPaintEngine::PaintEngineFeatures f = QPaintEngine::AllFeatures;
-    f &= ~(QPaintEngine::PorterDuff | QPaintEngine::PerspectiveTransform
+    f &= ~(QPaintEngine::PorterDuff
+           | QPaintEngine::PerspectiveTransform
            | QPaintEngine::ObjectBoundingModeGradients
-#ifndef USE_NATIVE_GRADIENTS
-           | QPaintEngine::LinearGradientFill
-#endif
-           | QPaintEngine::RadialGradientFill
            | QPaintEngine::ConicalGradientFill);
     return f;
 }
@@ -388,7 +385,7 @@ QByteArray AdvancedPdf::generateDashes(const QPen &pen)
 
 
 
-static const char* pattern_for_brush[] = {
+static const char* const pattern_for_brush[] = {
     0, // NoBrush
     0, // SolidPattern
     "0 J\n"
@@ -549,189 +546,6 @@ QByteArray AdvancedPdf::patternForBrush(const QBrush &b)
     return pattern_for_brush[style];
 }
 
-#ifdef USE_NATIVE_GRADIENTS
-static void writeTriangleLine(uchar *&data, int xpos, int ypos, int xoff, int yoff, uint rgb, uchar flag, bool alpha)
-{
-    data[0] =  flag;
-    data[1] = (uchar)(xpos >> 16);
-    data[2] = (uchar)(xpos >> 8);
-    data[3] = (uchar)(xpos >> 0);
-    data[4] = (uchar)(ypos >> 16);
-    data[5] = (uchar)(ypos >> 8);
-    data[6] = (uchar)(ypos >> 0);
-    data += 7;
-    if (alpha) {
-        *data++ = (uchar)qAlpha(rgb);
-    } else {
-        *data++ = (uchar)qRed(rgb);
-        *data++ = (uchar)qGreen(rgb);
-        *data++ = (uchar)qBlue(rgb);
-    }
-    xpos += xoff;
-    ypos += yoff;
-    data[0] =  flag;
-    data[1] = (uchar)(xpos >> 16);
-    data[2] = (uchar)(xpos >> 8);
-    data[3] = (uchar)(xpos >> 0);
-    data[4] = (uchar)(ypos >> 16);
-    data[5] = (uchar)(ypos >> 8);
-    data[6] = (uchar)(ypos >> 0);
-    data += 7;
-    if (alpha) {
-        *data++ = (uchar)qAlpha(rgb);
-    } else {
-        *data++ = (uchar)qRed(rgb);
-        *data++ = (uchar)qGreen(rgb);
-        *data++ = (uchar)qBlue(rgb);
-    }
-}
-
-
-QByteArray AdvancedPdf::generateLinearGradientShader(const QLinearGradient *gradient, const QPointF *page_rect, bool alpha)
-{
-    // generate list of triangles with colors
-    QPointF start = gradient->start();
-    QPointF stop = gradient->finalStop();
-    QGradientStops stops = gradient->stops();
-    QPointF offset = stop - start;
-    QGradient::Spread spread = gradient->spread();
-
-    if (gradient->spread() == QGradient::ReflectSpread) {
-        offset *= 2;
-        for (int i = stops.size() - 2; i >= 0; --i) {
-            QGradientStop stop = stops.at(i);
-            stop.first = 2. - stop.first;
-            stops.append(stop);
-        }
-        for (int i = 0 ; i < stops.size(); ++i)
-            stops[i].first /= 2.;
-    }
-
-    QPointF orthogonal(offset.y(), -offset.x());
-    qreal length = offset.x()*offset.x() + offset.y()*offset.y();
-
-    // find the max and min values in offset and orth direction that are needed to cover
-    // the whole page
-    int off_min = INT_MAX;
-    int off_max = INT_MIN;
-    qreal ort_min = INT_MAX;
-    qreal ort_max = INT_MIN;
-    for (int i = 0; i < 4; ++i) {
-        qreal off = ((page_rect[i].x() - start.x()) * offset.x() + (page_rect[i].y() - start.y()) * offset.y())/length;
-        qreal ort = ((page_rect[i].x() - start.x()) * orthogonal.x() + (page_rect[i].y() - start.y()) * orthogonal.y())/length;
-        off_min = qMin(off_min, qFloor(off));
-        off_max = qMax(off_max, qCeil(off));
-        ort_min = qMin(ort_min, ort);
-        ort_max = qMax(ort_max, ort);
-    }
-    ort_min -= 1;
-    ort_max += 1;
-
-    start += off_min * offset + ort_min * orthogonal;
-    orthogonal *= (ort_max - ort_min);
-    int num = off_max - off_min;
-
-    QPointF gradient_rect[4] = { start,
-                                 start + orthogonal,
-                                 start + num*offset,
-                                 start + num*offset + orthogonal };
-    qreal xmin = gradient_rect[0].x();
-    qreal xmax = gradient_rect[0].x();
-    qreal ymin = gradient_rect[0].y();
-    qreal ymax = gradient_rect[0].y();
-    for (int i = 1; i < 4; ++i) {
-        xmin = qMin(xmin, gradient_rect[i].x());
-        xmax = qMax(xmax, gradient_rect[i].x());
-        ymin = qMin(ymin, gradient_rect[i].y());
-        ymax = qMax(ymax, gradient_rect[i].y());
-    }
-    xmin -= 1000;
-    xmax += 1000;
-    ymin -= 1000;
-    ymax += 1000;
-    start -= QPointF(xmin, ymin);
-    qreal factor_x = qreal(1<<24)/(xmax - xmin);
-    qreal factor_y = qreal(1<<24)/(ymax - ymin);
-    int xoff = (int)(orthogonal.x()*factor_x);
-    int yoff = (int)(orthogonal.y()*factor_y);
-
-    QByteArray triangles;
-    triangles.resize(spread == QGradient::PadSpread ? 20*(stops.size()+2) : 20*num*stops.size());
-    uchar *data = (uchar *) triangles.data();
-    if (spread == QGradient::PadSpread) {
-        if (off_min > 0 || off_max < 1) {
-            // linear gradient outside of page
-            const QGradientStop &current_stop = off_min > 0 ? stops.at(stops.size()-1) : stops.at(0);
-            uint rgb = current_stop.second.rgba();
-            int xpos = (int)(start.x()*factor_x);
-            int ypos = (int)(start.y()*factor_y);
-            writeTriangleLine(data, xpos, ypos, xoff, yoff, rgb, 0, alpha);
-            start += num*offset;
-            xpos = (int)(start.x()*factor_x);
-            ypos = (int)(start.y()*factor_y);
-            writeTriangleLine(data, xpos, ypos, xoff, yoff, rgb, 1, alpha);
-        } else {
-            int flag = 0;
-            if (off_min < 0) {
-                uint rgb = stops.at(0).second.rgba();
-                int xpos = (int)(start.x()*factor_x);
-                int ypos = (int)(start.y()*factor_y);
-                writeTriangleLine(data, xpos, ypos, xoff, yoff, rgb, flag, alpha);
-                start -= off_min*offset;
-                flag = 1;
-            }
-            for (int s = 0; s < stops.size(); ++s) {
-                const QGradientStop &current_stop = stops.at(s);
-                uint rgb = current_stop.second.rgba();
-                int xpos = (int)(start.x()*factor_x);
-                int ypos = (int)(start.y()*factor_y);
-                writeTriangleLine(data, xpos, ypos, xoff, yoff, rgb, flag, alpha);
-                if (s < stops.size()-1)
-                    start += offset*(stops.at(s+1).first - stops.at(s).first);
-                flag = 1;
-            }
-            if (off_max > 1) {
-                start += (off_max - 1)*offset;
-                uint rgb = stops.at(stops.size()-1).second.rgba();
-                int xpos = (int)(start.x()*factor_x);
-                int ypos = (int)(start.y()*factor_y);
-                writeTriangleLine(data, xpos, ypos, xoff, yoff, rgb, flag, alpha);
-            }
-        }
-    } else {
-        for (int i = 0; i < num; ++i) {
-            uchar flag = 0;
-            for (int s = 0; s < stops.size(); ++s) {
-                uint rgb = stops.at(s).second.rgba();
-                int xpos = (int)(start.x()*factor_x);
-                int ypos = (int)(start.y()*factor_y);
-                writeTriangleLine(data, xpos, ypos, xoff, yoff, rgb, flag, alpha);
-                if (s < stops.size()-1)
-                    start += offset*(stops.at(s+1).first - stops.at(s).first);
-                flag = 1;
-            }
-        }
-    }
-    triangles.resize((char *)data - triangles.constData());
-
-    QByteArray shader;
-    AdvancedPdf::ByteStream s(&shader);
-    s << "<<\n"
-        "/ShadingType 4\n"
-        "/ColorSpace " << (alpha ? "/DeviceGray\n" : "/DeviceRGB\n") <<
-        "/AntiAlias true\n"
-        "/BitsPerCoordinate 24\n"
-        "/BitsPerComponent 8\n"
-        "/BitsPerFlag 8\n"
-        "/Decode [" << xmin << xmax << ymin << ymax << (alpha ? "0 1]\n" : "0 1 0 1 0 1]\n") <<
-        "/AntiAlias true\n"
-        "/Length " << triangles.length() << "\n"
-        ">>\n"
-        "stream\n" << triangles << "endstream\n"
-        "endobj\n";
-    return shader;
-}
-#endif
 
 static void moveToHook(qfixed x, qfixed y, void *data)
 {
@@ -1199,7 +1013,7 @@ void AdvancedPdfEngine::updateState(const QPaintEngineState &state)
         d->stroker.setPen(d->pen, state.renderHints());
         QBrush penBrush = d->pen.brush();
         bool oldSimple = d->simplePen;
-        d->simplePen = (d->hasPen && (penBrush.style() == Qt::SolidPattern) && penBrush.isOpaque());
+        d->simplePen = (d->hasPen && (penBrush.style() == Qt::SolidPattern) && penBrush.isOpaque() && d->opacity == 1.0);
         if (oldSimple != d->simplePen)
             flags |= DirtyTransform;
     } else if (flags & DirtyHints) {
@@ -1215,8 +1029,13 @@ void AdvancedPdfEngine::updateState(const QPaintEngineState &state)
         d->brushOrigin = state.brushOrigin();
         flags |= DirtyBrush;
     }
-    if (flags & DirtyOpacity)
+    if (flags & DirtyOpacity) {
         d->opacity = state.opacity();
+        if (d->simplePen && d->opacity != 1.0) {
+            d->simplePen = false;
+            flags |= DirtyTransform;
+        }
+    }
 
     bool ce = d->clipEnabled;
     if (flags & DirtyClipPath) {
@@ -1349,6 +1168,8 @@ void AdvancedPdfEngine::setPen()
     int pdfJoinStyle = 0;
     switch(d->pen.joinStyle()) {
     case Qt::MiterJoin:
+    case Qt::SvgMiterJoin:
+        *d->currentPage << d->pen.miterLimit() << "M ";
         pdfJoinStyle = 0;
         break;
     case Qt::BevelJoin:
@@ -1376,6 +1197,8 @@ void AdvancedPdfEngine::setBrush()
     bool specifyColor;
     int gStateObject = 0;
     int patternObject = d->addBrushPattern(d->stroker.matrix, &specifyColor, &gStateObject);
+    if (!patternObject && !specifyColor)
+        return;
 
     *d->currentPage << (patternObject ? "/PCSp cs " : "/CSp cs ");
     if (specifyColor) {
@@ -1422,19 +1245,60 @@ QPaintEngine::Type AdvancedPdfEngine::type() const
     return PaintEngineType;
 }
 
+void AdvancedPdfEngine::setResolution(int resolution)
+{
+    Q_D(AdvancedPdfEngine);
+    d->resolution = resolution;
+}
 
+int AdvancedPdfEngine::resolution() const
+{
+    Q_D(const AdvancedPdfEngine);
+    return d->resolution;
+}
 
+void AdvancedPdfEngine::setPageLayout(const QPageLayout &pageLayout)
+{
+    Q_D(AdvancedPdfEngine);
+    d->m_pageLayout = pageLayout;
+}
+
+void AdvancedPdfEngine::setPageSize(const QPageSize &pageSize)
+{
+    Q_D(AdvancedPdfEngine);
+    d->m_pageLayout.setPageSize(pageSize);
+}
+
+void AdvancedPdfEngine::setPageOrientation(QPageLayout::Orientation orientation)
+{
+    Q_D(AdvancedPdfEngine);
+    d->m_pageLayout.setOrientation(orientation);
+}
+
+void AdvancedPdfEngine::setPageMargins(const QMarginsF &margins, QPageLayout::Unit units)
+{
+    Q_D(AdvancedPdfEngine);
+    d->m_pageLayout.setUnits(units);
+    d->m_pageLayout.setMargins(margins);
+}
+
+QPageLayout AdvancedPdfEngine::pageLayout() const
+{
+    Q_D(const AdvancedPdfEngine);
+    return d->m_pageLayout;
+}
+
+// Metrics are in Device Pixels
 int AdvancedPdfEngine::metric(QPaintDevice::PaintDeviceMetric metricType) const
 {
     Q_D(const AdvancedPdfEngine);
     int val;
-    QRect r = d->pageRect();
     switch (metricType) {
     case QPaintDevice::PdmWidth:
-        val = r.width();
+        val = d->m_pageLayout.paintRectPixels(d->resolution).width();
         break;
     case QPaintDevice::PdmHeight:
-        val = r.height();
+        val = d->m_pageLayout.paintRectPixels(d->resolution).height();
         break;
     case QPaintDevice::PdmDpiX:
     case QPaintDevice::PdmDpiY:
@@ -1445,10 +1309,10 @@ int AdvancedPdfEngine::metric(QPaintDevice::PaintDeviceMetric metricType) const
         val = 1200;
         break;
     case QPaintDevice::PdmWidthMM:
-        val = qRound(r.width()*25.4/d->resolution);
+        val = qRound(d->m_pageLayout.paintRect(QPageLayout::Millimeter).width());
         break;
     case QPaintDevice::PdmHeightMM:
-        val = qRound(r.height()*25.4/d->resolution);
+        val = qRound(d->m_pageLayout.paintRect(QPageLayout::Millimeter).height());
         break;
     case QPaintDevice::PdmNumColors:
         val = INT_MAX;
@@ -1466,21 +1330,12 @@ int AdvancedPdfEngine::metric(QPaintDevice::PaintDeviceMetric metricType) const
     return val;
 }
 
-static inline QSizeF pageSizeToPostScriptPoints(const QSizeF &pageSizeMM)
-{
-#define Q_MM(n) int((n * 720 + 127) / 254)
-    return QSizeF(Q_MM(pageSizeMM.width()), Q_MM(pageSizeMM.height()));
-#undef Q_MM
-}
-
 AdvancedPdfEnginePrivate::AdvancedPdfEnginePrivate()
     : clipEnabled(false), allClipped(false), hasPen(true), hasBrush(false), simplePen(false),
       outDevice(0), ownsDevice(false),
-      fullPage(false), embedFonts(true),
-      landscape(false),
+      embedFonts(true),
       grayscale(false),
-      paperSize(pageSizeToPostScriptPoints(QSizeF(210, 297))), // A4
-      leftMargin(10), topMargin(10), rightMargin(10), bottomMargin(10) // ~3.5 mm
+      m_pageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF(10, 10, 10, 10))
 {
     resolution = 1200;
     currentObject = 1;
@@ -1492,11 +1347,6 @@ AdvancedPdfEnginePrivate::AdvancedPdfEnginePrivate()
     stream = new QDataStream;
 }
 
-void AdvancedPdfEnginePrivate::setPaperSize(const QSizeF &pageSizeMM)
-{
-    paperSize = pageSizeToPostScriptPoints(pageSizeMM);
-}
-
 bool AdvancedPdfEngine::begin(QPaintDevice *pdev)
 {
     Q_D(AdvancedPdfEngine);
@@ -1578,31 +1428,6 @@ AdvancedPdfEnginePrivate::~AdvancedPdfEnginePrivate()
     delete stream;
 }
 
-QRect AdvancedPdfEnginePrivate::paperRect() const
-{
-    int w = qRound(paperSize.width()*resolution/72.);
-    int h = qRound(paperSize.height()*resolution/72.);
-
-    if (!landscape)
-        return QRect(0, 0, w, h);
-    else
-        return QRect(0, 0, h, w);
-}
-
-QRect AdvancedPdfEnginePrivate::pageRect() const
-{
-    QRect r = paperRect();
-
-    if(!fullPage)
-        r.adjust(qRound(leftMargin*(resolution/72.)),
-                 qRound(topMargin*(resolution/72.)),
-                 -qRound(rightMargin*(resolution/72.)),
-                 -qRound(bottomMargin*(resolution/72.)));
-
-    return r;
-}
-
-
 void AdvancedPdfEnginePrivate::writeHeader()
 {
     addXrefEntry(0,false);
@@ -2112,34 +1937,263 @@ int AdvancedPdfEnginePrivate::writeImage(const QByteArray &data, int width, int
     return image;
 }
 
-#ifdef USE_NATIVE_GRADIENTS
-int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QMatrix &matrix, int *gStateObject)
+struct QGradientBound {
+    qreal start;
+    qreal stop;
+    int function;
+    bool reverse;
+};
+
+int AdvancedPdfEnginePrivate::createShadingFunction(const QGradient *gradient, int from, int to, bool reflect, bool alpha)
 {
-    const QGradient *gradient = b.gradient();
-    if (!gradient)
-        return 0;
+    QGradientStops stops = gradient->stops();
+    if (stops.isEmpty()) {
+        stops << QGradientStop(0, Qt::black);
+        stops << QGradientStop(1, Qt::white);
+    }
+    if (stops.at(0).first > 0)
+        stops.prepend(QGradientStop(0, stops.at(0).second));
+    if (stops.at(stops.size() - 1).first < 1)
+        stops.append(QGradientStop(1, stops.at(stops.size() - 1).second));
 
-    QTransform inv = matrix.inverted();
-    QPointF page_rect[4] = { inv.map(QPointF(0, 0)),
-                             inv.map(QPointF(width_, 0)),
-                             inv.map(QPointF(0, height_)),
-                             inv.map(QPointF(width_, height_)) };
+    QVector<int> functions;
+    for (int i = 0; i < stops.size() - 1; ++i) {
+        int f = addXrefEntry(-1);
+        QByteArray data;
+        AdvancedPdf::ByteStream s(&data);
+        s << "<<\n"
+             "/FunctionType 2\n"
+             "/Domain [0 1]\n"
+             "/N 1\n";
+        if (alpha) {
+            s << "/C0 [" << stops.at(i).second.alphaF() << "]\n"
+                 "/C1 [" << stops.at(i + 1).second.alphaF() << "]\n";
+        } else {
+            s << "/C0 [" << stops.at(i).second.redF() << stops.at(i).second.greenF() <<  stops.at(i).second.blueF() << "]\n"
+                 "/C1 [" << stops.at(i + 1).second.redF() << stops.at(i + 1).second.greenF() <<  stops.at(i + 1).second.blueF() << "]\n";
+        }
+        s << ">>\n"
+             "endobj\n";
+        write(data);
+        functions << f;
+    }
 
-    bool opaque = b.isOpaque();
+    QVector<QGradientBound> gradientBounds;
+
+    for (int step = from; step < to; ++step) {
+        if (reflect && step % 2) {
+            for (int i = stops.size() - 1; i > 0; --i) {
+                QGradientBound b;
+                b.start = step + 1 - qBound(qreal(0.), stops.at(i).first, qreal(1.));
+                b.stop = step + 1 - qBound(qreal(0.), stops.at(i - 1).first, qreal(1.));
+                b.function = functions.at(i - 1);
+                b.reverse = true;
+                gradientBounds << b;
+            }
+        } else {
+            for (int i = 0; i < stops.size() - 1; ++i) {
+                QGradientBound b;
+                b.start = step + qBound(qreal(0.), stops.at(i).first, qreal(1.));
+                b.stop = step + qBound(qreal(0.), stops.at(i + 1).first, qreal(1.));
+                b.function = functions.at(i);
+                b.reverse = false;
+                gradientBounds << b;
+            }
+        }
+    }
+
+    // normalize bounds to [0..1]
+    qreal bstart = gradientBounds.at(0).start;
+    qreal bend = gradientBounds.at(gradientBounds.size() - 1).stop;
+    qreal norm = 1./(bend - bstart);
+    for (int i = 0; i < gradientBounds.size(); ++i) {
+        gradientBounds[i].start = (gradientBounds[i].start - bstart)*norm;
+        gradientBounds[i].stop = (gradientBounds[i].stop - bstart)*norm;
+    }
+
+    int function;
+    if (gradientBounds.size() > 1) {
+        function = addXrefEntry(-1);
+        QByteArray data;
+        AdvancedPdf::ByteStream s(&data);
+        s << "<<\n"
+             "/FunctionType 3\n"
+             "/Domain [0 1]\n"
+             "/Bounds [";
+        for (int i = 1; i < gradientBounds.size(); ++i)
+            s << gradientBounds.at(i).start;
+        s << "]\n"
+             "/Encode [";
+        for (int i = 0; i < gradientBounds.size(); ++i)
+            s << (gradientBounds.at(i).reverse ? "1 0 " : "0 1 ");
+        s << "]\n"
+             "/Functions [";
+        for (int i = 0; i < gradientBounds.size(); ++i)
+            s << gradientBounds.at(i).function << "0 R ";
+        s << "]\n"
+             ">>\n";
+        write(data);
+    } else {
+        function = functions.at(0);
+    }
+    return function;
+}
+
+int AdvancedPdfEnginePrivate::generateLinearGradientShader(const QLinearGradient *gradient, const QTransform &matrix, bool alpha)
+{
+    QPointF start = gradient->start();
+    QPointF stop = gradient->finalStop();
+    QPointF offset = stop - start;
+    Q_ASSERT(gradient->coordinateMode() == QGradient::LogicalMode);
+
+    int from = 0;
+    int to = 1;
+    bool reflect = false;
+    switch (gradient->spread()) {
+    case QGradient::PadSpread:
+        break;
+    case QGradient::ReflectSpread:
+        reflect = true;
+        // fall through
+    case QGradient::RepeatSpread: {
+        // calculate required bounds
+        QRectF pageRect = m_pageLayout.fullRectPixels(resolution);
+        QTransform inv = matrix.inverted();
+        QPointF page_rect[4] = { inv.map(pageRect.topLeft()),
+                                 inv.map(pageRect.topRight()),
+                                 inv.map(pageRect.bottomLeft()),
+                                 inv.map(pageRect.bottomRight()) };
+
+        qreal length = offset.x()*offset.x() + offset.y()*offset.y();
+
+        // find the max and min values in offset and orth direction that are needed to cover
+        // the whole page
+        from = INT_MAX;
+        to = INT_MIN;
+        for (int i = 0; i < 4; ++i) {
+            qreal off = ((page_rect[i].x() - start.x()) * offset.x() + (page_rect[i].y() - start.y()) * offset.y())/length;
+            from = qMin(from, qFloor(off));
+            to = qMax(to, qCeil(off));
+        }
+
+        stop = start + to * offset;
+        start = start + from * offset;\
+        break;
+    }
+    }
+
+    int function = createShadingFunction(gradient, from, to, reflect, alpha);
 
     QByteArray shader;
-    QByteArray alphaShader;
-    if (gradient->type() == QGradient::LinearGradient) {
-        const QLinearGradient *lg = static_cast<const QLinearGradient *>(gradient);
-        shader = AdvancedPdf::generateLinearGradientShader(lg, page_rect);
-        if (!opaque)
-            alphaShader = AdvancedPdf::generateLinearGradientShader(lg, page_rect, true);
-    } else {
-        // #############
-        return 0;
-    }
+    AdvancedPdf::ByteStream s(&shader);
+    s << "<<\n"
+        "/ShadingType 2\n"
+        "/ColorSpace " << (alpha ? "/DeviceGray\n" : "/DeviceRGB\n") <<
+        "/AntiAlias true\n"
+        "/Coords [" << start.x() << start.y() << stop.x() << stop.y() << "]\n"
+        "/Extend [true true]\n"
+        "/Function " << function << "0 R\n"
+        ">>\n"
+        "endobj\n";
     int shaderObject = addXrefEntry(-1);
     write(shader);
+    return shaderObject;
+}
+
+int AdvancedPdfEnginePrivate::generateRadialGradientShader(const QRadialGradient *gradient, const QTransform &matrix, bool alpha)
+{
+    QPointF p1 = gradient->center();
+    double r1 = gradient->centerRadius();
+    QPointF p0 = gradient->focalPoint();
+    double r0 = gradient->focalRadius();
+
+    Q_ASSERT(gradient->coordinateMode() == QGradient::LogicalMode);
+
+    int from = 0;
+    int to = 1;
+    bool reflect = false;
+    switch (gradient->spread()) {
+    case QGradient::PadSpread:
+        break;
+    case QGradient::ReflectSpread:
+        reflect = true;
+        // fall through
+    case QGradient::RepeatSpread: {
+        Q_ASSERT(qFuzzyIsNull(r0)); // QPainter emulates if this is not 0
+
+        QRectF pageRect = m_pageLayout.fullRectPixels(resolution);
+        QTransform inv = matrix.inverted();
+        QPointF page_rect[4] = { inv.map(pageRect.topLeft()),
+                                 inv.map(pageRect.topRight()),
+                                 inv.map(pageRect.bottomLeft()),
+                                 inv.map(pageRect.bottomRight()) };
+
+        // increase to until the whole page fits into it
+        bool done = false;
+        while (!done) {
+            QPointF center = QPointF(p0.x() + to*(p1.x() - p0.x()), p0.y() + to*(p1.y() - p0.y()));
+            double radius = r0 + to*(r1 - r0);
+            double r2 = radius*radius;
+            done = true;
+            for (int i = 0; i < 4; ++i) {
+                QPointF off = page_rect[i] - center;
+                if (off.x()*off.x() + off.y()*off.y() > r2) {
+                    ++to;
+                    done = false;
+                    break;
+                }
+            }
+        }
+        p1 = QPointF(p0.x() + to*(p1.x() - p0.x()), p0.y() + to*(p1.y() - p0.y()));
+        r1 = r0 + to*(r1 - r0);
+        break;
+    }
+    }
+
+    int function = createShadingFunction(gradient, from, to, reflect, alpha);
+
+    QByteArray shader;
+    AdvancedPdf::ByteStream s(&shader);
+    s << "<<\n"
+        "/ShadingType 3\n"
+        "/ColorSpace " << (alpha ? "/DeviceGray\n" : "/DeviceRGB\n") <<
+        "/AntiAlias true\n"
+        "/Domain [0 1]\n"
+        "/Coords [" << p0.x() << p0.y() << r0 << p1.x() << p1.y() << r1 << "]\n"
+        "/Extend [true true]\n"
+        "/Function " << function << "0 R\n"
+        ">>\n"
+        "endobj\n";
+    int shaderObject = addXrefEntry(-1);
+    write(shader);
+    return shaderObject;
+}
+
+int AdvancedPdfEnginePrivate::generateGradientShader(const QGradient *gradient, const QTransform &matrix, bool alpha)
+{
+    switch (gradient->type()) {
+    case QGradient::LinearGradient:
+        return generateLinearGradientShader(static_cast<const QLinearGradient *>(gradient), matrix, alpha);
+    case QGradient::RadialGradient:
+        return generateRadialGradientShader(static_cast<const QRadialGradient *>(gradient), matrix, alpha);
+    case QGradient::ConicalGradient:
+    default:
+        qWarning() << "Implement me!";
+    }
+    return 0;
+}
+
+int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QTransform &matrix, int *gStateObject)
+{
+    const QGradient *gradient = b.gradient();
+
+    if (!gradient || gradient->coordinateMode() != QGradient::LogicalMode)
+        return 0;
+
+    QRectF pageRect = m_pageLayout.fullRectPixels(resolution);
+
+    QTransform m = b.transform() * matrix;
+    int shaderObject = generateGradientShader(gradient, m);
 
     QByteArray str;
     AdvancedPdf::ByteStream s(&str);
@@ -2148,12 +2202,12 @@ int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QMatrix &matr
         "/PatternType 2\n"
         "/Shading " << shaderObject << "0 R\n"
         "/Matrix ["
-      << matrix.m11()
-      << matrix.m12()
-      << matrix.m21()
-      << matrix.m22()
-      << matrix.dx()
-      << matrix.dy() << "]\n";
+      << m.m11()
+      << m.m12()
+      << m.m21()
+      << m.m22()
+      << m.dx()
+      << m.dy() << "]\n";
     s << ">>\n"
         "endobj\n";
 
@@ -2161,7 +2215,7 @@ int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QMatrix &matr
     write(str);
     currentPage->patterns.append(patternObj);
 
-    if (!opaque) {
+    if (!b.isOpaque()) {
         bool ca = true;
         QGradientStops stops = gradient->stops();
         int a = stops.at(0).second.alpha();
@@ -2174,8 +2228,7 @@ int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QMatrix &matr
         if (ca) {
             *gStateObject = addConstantAlphaObject(stops.at(0).second.alpha());
         } else {
-            int alphaShaderObject = addXrefEntry(-1);
-            write(alphaShader);
+            int alphaShaderObject = generateGradientShader(gradient, m, true);
 
             QByteArray content;
             AdvancedPdf::ByteStream c(&content);
@@ -2186,7 +2239,7 @@ int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QMatrix &matr
             f << "<<\n"
                 "/Type /XObject\n"
                 "/Subtype /Form\n"
-                "/BBox [0 0 " << width_ << height_ << "]\n"
+                "/BBox [0 0 " << pageRect.width() << pageRect.height() << "]\n"
                 "/Group <</S /Transparency >>\n"
                 "/Resources <<\n"
                 "/Shading << /Shader" << alphaShaderObject << alphaShaderObject << "0 R >>\n"
@@ -2210,7 +2263,6 @@ int AdvancedPdfEnginePrivate::gradientBrush(const QBrush &b, const QMatrix &matr
 
     return patternObj;
 }
-#endif
 
 int AdvancedPdfEnginePrivate::addConstantAlphaObject(int brushAlpha, int penAlpha)
 {
@@ -2232,6 +2284,7 @@ int AdvancedPdfEnginePrivate::addConstantAlphaObject(int brushAlpha, int penAlph
     return object;
 }
 
+
 int AdvancedPdfEnginePrivate::addBrushPattern(const QTransform &m, bool *specifyColor, int *gStateObject)
 {
     int paintType = 2; // Uncolored tiling
@@ -2247,13 +2300,9 @@ int AdvancedPdfEnginePrivate::addBrushPattern(const QTransform &m, bool *specify
     //qDebug() << brushOrigin << matrix;
 
     Qt::BrushStyle style = brush.style();
-    if (style == Qt::LinearGradientPattern) {// && style <= Qt::ConicalGradientPattern) {
-#ifdef USE_NATIVE_GRADIENTS
+    if (style == Qt::LinearGradientPattern || style == Qt::RadialGradientPattern) {// && style <= Qt::ConicalGradientPattern) {
         *specifyColor = false;
-        return gradientBrush(b, matrix, gStateObject);
-#else
-        return 0;
-#endif
+        return gradientBrush(brush, matrix, gStateObject);
     }
 
     if ((!brush.isOpaque() && brush.style() < Qt::LinearGradientPattern) || opacity != 1.0)
@@ -2265,9 +2314,9 @@ int AdvancedPdfEnginePrivate::addBrushPattern(const QTransform &m, bool *specify
     if (pattern.isEmpty()) {
         if (brush.style() != Qt::TexturePattern)
             return 0;
-        QImage image = brush.texture().toImage();
+        QImage image = brush.textureImage();
         bool bitmap = true;
-        imageObject = addImage(image, &bitmap, brush.texture().cacheKey());
+        imageObject = addImage(image, &bitmap, image.cacheKey());
         if (imageObject != -1) {
             QImage::Format f = image.format();
             if (f != QImage::Format_MonoLSB && f != QImage::Format_Mono) {
@@ -2318,6 +2367,14 @@ int AdvancedPdfEnginePrivate::addBrushPattern(const QTransform &m, bool *specify
     return patternObj;
 }
 
+static inline bool is_monochrome(const QVector<QRgb> &colorTable)
+{
+    return colorTable.size() == 2
+        && colorTable.at(0) == QColor(Qt::black).rgba()
+        && colorTable.at(1) == QColor(Qt::white).rgba()
+        ;
+}
+
 /*!
  * Adds an image to the pdf and return the pdf-object id. Returns -1 if adding the image failed.
  */
@@ -2332,10 +2389,7 @@ int AdvancedPdfEnginePrivate::addImage(const QImage &img, bool *bitmap, qint64 s
 
     QImage image = img;
     QImage::Format format = image.format();
-    if (image.depth() == 1 && *bitmap && img.colorTable().size() == 2
-        && img.colorTable().at(0) == QColor(Qt::black).rgba()
-        && img.colorTable().at(1) == QColor(Qt::white).rgba())
-    {
+    if (image.depth() == 1 && *bitmap && is_monochrome(img.colorTable())) {
         if (format == QImage::Format_MonoLSB)
             image = image.convertToFormat(QImage::Format_Mono);
         format = QImage::Format_Mono;
@@ -2357,7 +2411,7 @@ int AdvancedPdfEnginePrivate::addImage(const QImage &img, bool *bitmap, qint64 s
         data.resize(bytesPerLine * h);
         char *rawdata = data.data();
         for (int y = 0; y < h; ++y) {
-            memcpy(rawdata, image.scanLine(y), bytesPerLine);
+            memcpy(rawdata, image.constScanLine(y), bytesPerLine);
             rawdata += bytesPerLine;
         }
         object = writeImage(data, w, h, d, 0, 0);
@@ -2379,7 +2433,7 @@ int AdvancedPdfEnginePrivate::addImage(const QImage &img, bool *bitmap, qint64 s
                 softMaskData.resize(w * h);
                 uchar *sdata = (uchar *)softMaskData.data();
                 for (int y = 0; y < h; ++y) {
-                    const QRgb *rgb = (const QRgb *)image.scanLine(y);
+                    const QRgb *rgb = (const QRgb *)image.constScanLine(y);
                     for (int x = 0; x < w; ++x) {
                         uchar alpha = qAlpha(*rgb);
                         *sdata++ = alpha;
@@ -2395,7 +2449,7 @@ int AdvancedPdfEnginePrivate::addImage(const QImage &img, bool *bitmap, qint64 s
             softMaskData.resize(w * h);
             uchar *sdata = (uchar *)softMaskData.data();
             for (int y = 0; y < h; ++y) {
-                const QRgb *rgb = (const QRgb *)image.scanLine(y);
+                const QRgb *rgb = (const QRgb *)image.constScanLine(y);
                 if (grayscale) {
                     for (int x = 0; x < w; ++x) {
                         *(data++) = qGray(*rgb);
@@ -2500,7 +2554,8 @@ void AdvancedPdfEnginePrivate::drawTextItem(const QPointF &p, const QTextItemInt
 
     QFontEngine::FaceId face_id = fe->faceId();
     bool noEmbed = false;
-    if (face_id.filename.isEmpty()
+    if (!embedFonts
+        || face_id.filename.isEmpty()
         || fe->fsType & 0x200 /* bitmap embedding only */
         || fe->fsType == 2 /* no embedding allowed */) {
         *currentPage << "Q\n";
@@ -2523,10 +2578,6 @@ void AdvancedPdfEnginePrivate::drawTextItem(const QPointF &p, const QTextItemInt
 
     qreal size = ti.fontEngine->fontDef.pixelSize;
 
-#if defined(Q_OS_WIN)
-    size = (ti.fontEngine->ascent() + ti.fontEngine->descent()).toReal();
-#endif
-
     QVarLengthArray<glyph_t> glyphs;
     QVarLengthArray<QFixedPoint> positions;
     QTransform m = QTransform::fromTranslate(p.x(), p.y());
@@ -2612,9 +2663,9 @@ void AdvancedPdfEnginePrivate::drawTextItem(const QPointF &p, const QTextItemInt
 QTransform AdvancedPdfEnginePrivate::pageMatrix() const
 {
     qreal scale = 72./resolution;
-    QTransform tmp(scale, 0.0, 0.0, -scale, 0.0, height());
-    if (!fullPage) {
-        QRect r = pageRect();
+    QTransform tmp(scale, 0.0, 0.0, -scale, 0.0, m_pageLayout.fullRectPoints().height());
+    if (m_pageLayout.mode() != QPageLayout::FullPageMode) {
+        QRect r = m_pageLayout.paintRectPixels(resolution);
         tmp.translate(r.left(), r.top());
     }
     return tmp;
@@ -2623,12 +2674,12 @@ QTransform AdvancedPdfEnginePrivate::pageMatrix() const
 void AdvancedPdfEnginePrivate::newPage()
 {
     if (currentPage && currentPage->pageSize.isEmpty())
-        currentPage->pageSize = QSize(width(), height());
+        currentPage->pageSize = m_pageLayout.fullRectPoints().size();
     writePage();
 
     delete currentPage;
     currentPage = new AdvancedPdfPage;
-    currentPage->pageSize = QSize(width(), height());
+    currentPage->pageSize = m_pageLayout.fullRectPoints().size();
     stroker.stream = currentPage;
     pages.append(requestObject());
 
