@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2015, 2017 Kai Pastor
+ *    Copyright 2012-2015, 2017-2020, 2025 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -21,16 +21,26 @@
 
 #include "template_adjust.h"
 
+#include <Qt>
 #include <QAbstractItemView>
 #include <QAction>
 #include <QCheckBox>
+#include <QCursor>
+#include <QEvent>
 #include <QHeaderView>
+#include <QIcon>
 #include <QLabel>
+#include <QLatin1Char>
 #include <QMessageBox>
 #include <QMouseEvent>
 #include <QPainter>
+#include <QPixmap>
+#include <QPoint>
+#include <QPointF>
 #include <QPushButton>
+#include <QRectF>
 #include <QTableWidget>
+#include <QTableWidgetItem>
 #include <QToolBar>
 #include <QVBoxLayout>
 
@@ -329,7 +339,7 @@ void TemplateAdjustWidget::deletePassPoint(int number)
 
 void TemplateAdjustWidget::stopTemplateAdjust()
 {
-	// If one of these is checked, the corresponding tool should be set. The last condition is just to be sure.
+	// If one of these is checked, the corresponding tool should be unset. The last condition is just to be sure.
 	if ((new_act->isChecked() || move_act->isChecked() || delete_act->isChecked()) && controller->getTool())
 	{
 		controller->setTool(nullptr);
@@ -344,18 +354,11 @@ void TemplateAdjustWidget::updateActions()
 	clear_and_revert_button->setEnabled(has_pass_points);
 	move_act->setEnabled(has_pass_points);
 	delete_act->setEnabled(has_pass_points);
-	if (! has_pass_points)
+	if (!has_pass_points && (move_act->isChecked() || delete_act->isChecked()))
 	{
-		if (move_act->isChecked())
-		{
-			move_act->setChecked(false);
-			moveClicked(false);
-		}
-		if (delete_act->isChecked())
-		{
-			delete_act->setChecked(false);
-			deleteClicked(false);
-		}
+		move_act->setChecked(false);
+		delete_act->setChecked(false);
+		controller->setTool(nullptr);
 	}
 }
 
