@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012-2014 Thomas Schöps
- *    Copyright 2013-2017 Kai Pastor
+ *    Copyright 2013-2020, 2024 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -21,9 +21,9 @@
 
 #include "edit_point_tool.h"
 
+#include <limits>
 #include <map>
 #include <memory>
-#include <limits>
 #include <vector>
 
 #include <QtGlobal>
@@ -48,7 +48,6 @@
 #include "core/objects/object.h"
 #include "core/objects/object_mover.h"
 #include "core/objects/text_object.h"
-#include "core/symbols/line_symbol.h"
 #include "core/symbols/symbol.h"
 #include "gui/modifier_key.h"
 #include "gui/map/map_editor.h"
@@ -98,11 +97,7 @@ EditPointTool::~EditPointTool()
 bool EditPointTool::addDashPointDefault() const
 {
 	// Toggle dash points depending on if the selected symbol has a dash symbol.
-	// TODO: instead of just looking if it is a line symbol with dash points,
-	// could also check for combined symbols containing lines with dash points
-	return ( hover_object &&
-	         hover_object->getSymbol()->getType() == Symbol::Line &&
-	         hover_object->getSymbol()->asLine()->getDashSymbol() != nullptr );
+	return (hover_object && hover_object->getSymbol()->containsDashSymbol());
 }
 
 bool EditPointTool::mousePressEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget)
@@ -185,7 +180,7 @@ void EditPointTool::clickPress()
 			startDragging();
 			hover_state = OverObjectNode;
 			hover_point = path->subdivide(closest.path_coord);
-			if (addDashPointDefault() ^ switch_dash_points)
+			if (addDashPointDefault() != switch_dash_points)
 			{
 				auto point = path->getCoordinate(hover_point);
 				point.setDashPoint(true);
@@ -485,9 +480,7 @@ bool EditPointTool::keyRelease(QKeyEvent* event)
 		
 	case Qt::Key_Shift:
 		snap_helper->setFilter(SnappingToolHelper::NoSnapping);
-		if (hoveringOverCurveHandle())
-			reapplyConstraintHelpers();
-		else if (editingInProgress())
+		if (hoveringOverCurveHandle() || editingInProgress())
 			reapplyConstraintHelpers();
 		updateStatusText();
 		return false; // not consuming Shift
