@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2013-2019 Kai Pastor
+ *    Copyright 2013-2020, 2025 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -179,14 +179,19 @@ void RotatePatternTool::dragMove()
 	
 	for (auto object : editedObjects())
 	{
-		if (object->getSymbol()->isRotatable())
+		switch (object->getType())
 		{
-			object->setRotation(rotation);
-		}
-		else if (object->getType() == Object::Path)
-		{
-			object->asPath()->setPatternOrigin(MapCoord(click_pos_map));
-			object->asPath()->setPatternRotation(rotation);
+		case Object::Path:
+			if (object->getSymbol()->hasRotatableFillPattern())
+			{
+				auto* path = object->asPath();
+				path->setPatternOrigin(MapCoord(click_pos_map));
+				path->setPatternRotation(rotation);
+			}
+			break;
+		default:
+			if (object->getSymbol()->isRotatable())
+				object->setRotation(rotation);
 		}
 	}
 	
